@@ -5,36 +5,44 @@
  *
  * @package PhpMyAdmin
  */
+declare(strict_types=1);
 
 use PhpMyAdmin\Core;
+use PhpMyAdmin\DatabaseInterface;
 use PhpMyAdmin\Encoding;
 use PhpMyAdmin\Export;
 use PhpMyAdmin\Plugins;
 use PhpMyAdmin\Plugins\ExportPlugin;
 use PhpMyAdmin\Relation;
+use PhpMyAdmin\Response;
 use PhpMyAdmin\Sanitize;
+use PhpMyAdmin\SqlParser\Parser;
+use PhpMyAdmin\SqlParser\Statements\SelectStatement;
+use PhpMyAdmin\SqlParser\Utils\Misc;
 use PhpMyAdmin\Url;
 use PhpMyAdmin\Util;
-use PhpMyAdmin\Response;
 
-/**
- * Get the variables sent or posted to this script and a core script
- */
-include_once 'libraries/common.inc.php';
-/**
- * If we are sending the export file (as opposed to just displaying it
- * as text), we have to bypass the usual PhpMyAdmin\Response mechanism
- */
-if (isset($_POST['output_format']) && $_POST['output_format'] == 'sendit') {
-    $response = Response::getInstance();
-    $response->disable();
+if (! defined('ROOT_PATH')) {
+    define('ROOT_PATH', __DIR__ . DIRECTORY_SEPARATOR);
 }
 
-$response = Response::getInstance();
-$header   = $response->getHeader();
-$scripts  = $header->getScripts();
+global $db, $sql_query;
+
+include_once ROOT_PATH . 'libraries/common.inc.php';
+
+/** @var Response $response */
+$response = $containerBuilder->get(Response::class);
+
+/** @var DatabaseInterface $dbi */
+$dbi = $containerBuilder->get(DatabaseInterface::class);
+
+$header = $response->getHeader();
+$scripts = $header->getScripts();
 $scripts->addFile('export_output.js');
 
+/** @var Export $export */
+$export = $containerBuilder->get('export');
+
 //check if it's the GET request to check export time out
 if (isset($_GET['check_time_out'])) {
     if (isset($_SESSION['pma_export_error'])) {
@@ -46,6 +54,7 @@ if (isset($_GET['check_time_out'])) {
     }
     exit;
 }
+
 /**
  * Sets globals from $_POST
  *
@@ -55,123 +64,125 @@ if (isset($_GET['check_time_out'])) {
  * TODO: this should be removed to avoid passing user input to GLOBALS
  * without checking
  */
-$post_params = array(
-        'db',
-        'table',
-        'what',
-        'single_table',
-        'export_type',
-        'export_method',
-        'quick_or_custom',
-        'db_select',
-        'table_select',
-        'table_structure',
-        'table_data',
-        'limit_to',
-        'limit_from',
-        'allrows',
-        'lock_tables',
-        'output_format',
-        'filename_template',
-        'maxsize',
-        'remember_template',
-        'charset',
-        'compression',
-        'as_separate_files',
-        'knjenc',
-        'xkana',
-        'htmlword_structure_or_data',
-        'htmlword_null',
-        'htmlword_columns',
-        'mediawiki_headers',
-        'mediawiki_structure_or_data',
-        'mediawiki_caption',
-        'pdf_structure_or_data',
-        'odt_structure_or_data',
-        'odt_relation',
-        'odt_comments',
-        'odt_mime',
-        'odt_columns',
-        'odt_null',
-        'codegen_structure_or_data',
-        'codegen_format',
-        'excel_null',
-        'excel_removeCRLF',
-        'excel_columns',
-        'excel_edition',
-        'excel_structure_or_data',
-        'yaml_structure_or_data',
-        'ods_null',
-        'ods_structure_or_data',
-        'ods_columns',
-        'json_structure_or_data',
-        'json_pretty_print',
-        'json_unicode',
-        'xml_structure_or_data',
-        'xml_export_events',
-        'xml_export_functions',
-        'xml_export_procedures',
-        'xml_export_tables',
-        'xml_export_triggers',
-        'xml_export_views',
-        'xml_export_contents',
-        'texytext_structure_or_data',
-        'texytext_columns',
-        'texytext_null',
-        'phparray_structure_or_data',
-        'sql_include_comments',
-        'sql_header_comment',
-        'sql_dates',
-        'sql_relation',
-        'sql_mime',
-        'sql_use_transaction',
-        'sql_disable_fk',
-        'sql_compatibility',
-        'sql_structure_or_data',
-        'sql_create_database',
-        'sql_drop_table',
-        'sql_procedure_function',
-        'sql_create_table',
-        'sql_create_view',
-        'sql_create_trigger',
-        'sql_if_not_exists',
-        'sql_auto_increment',
-        'sql_backquotes',
-        'sql_truncate',
-        'sql_delayed',
-        'sql_ignore',
-        'sql_type',
-        'sql_insert_syntax',
-        'sql_max_query_size',
-        'sql_hex_for_binary',
-        'sql_utc_time',
-        'sql_drop_database',
-        'sql_views_as_tables',
-        'sql_metadata',
-        'csv_separator',
-        'csv_enclosed',
-        'csv_escaped',
-        'csv_terminated',
-        'csv_null',
-        'csv_removeCRLF',
-        'csv_columns',
-        'csv_structure_or_data',
-        // csv_replace should have been here but we use it directly from $_POST
-        'latex_caption',
-        'latex_structure_or_data',
-        'latex_structure_caption',
-        'latex_structure_continued_caption',
-        'latex_structure_label',
-        'latex_relation',
-        'latex_comments',
-        'latex_mime',
-        'latex_columns',
-        'latex_data_caption',
-        'latex_data_continued_caption',
-        'latex_data_label',
-        'latex_null',
-        'aliases'
-);
+$post_params = [
+    'db',
+    'table',
+    'what',
+    'single_table',
+    'export_type',
+    'export_method',
+    'quick_or_custom',
+    'db_select',
+    'table_select',
+    'table_structure',
+    'table_data',
+    'limit_to',
+    'limit_from',
+    'allrows',
+    'lock_tables',
+    'output_format',
+    'filename_template',
+    'maxsize',
+    'remember_template',
+    'charset',
+    'compression',
+    'as_separate_files',
+    'knjenc',
+    'xkana',
+    'htmlword_structure_or_data',
+    'htmlword_null',
+    'htmlword_columns',
+    'mediawiki_headers',
+    'mediawiki_structure_or_data',
+    'mediawiki_caption',
+    'pdf_structure_or_data',
+    'odt_structure_or_data',
+    'odt_relation',
+    'odt_comments',
+    'odt_mime',
+    'odt_columns',
+    'odt_null',
+    'codegen_structure_or_data',
+    'codegen_format',
+    'excel_null',
+    'excel_removeCRLF',
+    'excel_columns',
+    'excel_edition',
+    'excel_structure_or_data',
+    'yaml_structure_or_data',
+    'ods_null',
+    'ods_structure_or_data',
+    'ods_columns',
+    'json_structure_or_data',
+    'json_pretty_print',
+    'json_unicode',
+    'xml_structure_or_data',
+    'xml_export_events',
+    'xml_export_functions',
+    'xml_export_procedures',
+    'xml_export_tables',
+    'xml_export_triggers',
+    'xml_export_views',
+    'xml_export_contents',
+    'texytext_structure_or_data',
+    'texytext_columns',
+    'texytext_null',
+    'phparray_structure_or_data',
+    'sql_include_comments',
+    'sql_header_comment',
+    'sql_dates',
+    'sql_relation',
+    'sql_mime',
+    'sql_use_transaction',
+    'sql_disable_fk',
+    'sql_compatibility',
+    'sql_structure_or_data',
+    'sql_create_database',
+    'sql_drop_table',
+    'sql_procedure_function',
+    'sql_create_table',
+    'sql_create_view',
+    'sql_create_trigger',
+    'sql_view_current_user',
+    'sql_if_not_exists',
+    'sql_or_replace_view',
+    'sql_auto_increment',
+    'sql_backquotes',
+    'sql_truncate',
+    'sql_delayed',
+    'sql_ignore',
+    'sql_type',
+    'sql_insert_syntax',
+    'sql_max_query_size',
+    'sql_hex_for_binary',
+    'sql_utc_time',
+    'sql_drop_database',
+    'sql_views_as_tables',
+    'sql_metadata',
+    'csv_separator',
+    'csv_enclosed',
+    'csv_escaped',
+    'csv_terminated',
+    'csv_null',
+    'csv_removeCRLF',
+    'csv_columns',
+    'csv_structure_or_data',
+    // csv_replace should have been here but we use it directly from $_POST
+    'latex_caption',
+    'latex_structure_or_data',
+    'latex_structure_caption',
+    'latex_structure_continued_caption',
+    'latex_structure_label',
+    'latex_relation',
+    'latex_comments',
+    'latex_mime',
+    'latex_columns',
+    'latex_data_caption',
+    'latex_data_continued_caption',
+    'latex_data_label',
+    'latex_null',
+    'aliases',
+];
 
 foreach ($post_params as $one_post_param) {
     if (isset($_POST[$one_post_param])) {
@@ -181,21 +192,21 @@ foreach ($post_params as $one_post_param) {
 
 $table = $GLOBALS['table'];
 
-PhpMyAdmin\Util::checkParameters(array('what', 'export_type'));
+PhpMyAdmin\Util::checkParameters(['what', 'export_type']);
 
 // sanitize this parameter which will be used below in a file inclusion
 $what = Core::securePath($_POST['what']);
 
 // export class instance, not array of properties, as before
-/* @var $export_plugin ExportPlugin */
+/** @var ExportPlugin $export_plugin */
 $export_plugin = Plugins::getPlugin(
     "export",
     $what,
     'libraries/classes/Plugins/Export/',
-    array(
+    [
         'export_type' => $export_type,
-        'single_table' => isset($single_table)
-    )
+        'single_table' => isset($single_table),
+    ]
 );
 
 // Check export type
@@ -206,15 +217,15 @@ if (empty($export_plugin)) {
 /**
  * valid compression methods
  */
-$compression_methods = array(
+$compression_methods = [
     'zip',
-    'gzip'
-);
+    'gzip',
+];
 
 /**
  * init and variable checking
  */
-$compression = false;
+$compression = '';
 $onserver = false;
 $save_on_server = false;
 $buffer_needed = false;
@@ -266,22 +277,36 @@ if ($_POST['output_format'] == 'astext') {
     }
 }
 
+/**
+ * If we are sending the export file (as opposed to just displaying it
+ * as text), we have to bypass the usual PhpMyAdmin\Response mechanism
+ */
+if (isset($_POST['output_format']) && $_POST['output_format'] == 'sendit' && ! $save_on_server) {
+    $response->disable();
+    //Disable all active buffers (see: ob_get_status(true) at this point)
+    do {
+        $hasBuffer = @ob_end_clean();
+    } while ($hasBuffer);
+}
+
+$tables = [];
 // Generate error url and check for needed variables
 if ($export_type == 'server') {
     $err_url = 'server_export.php' . Url::getCommon();
 } elseif ($export_type == 'database' && strlen($db) > 0) {
-    $err_url = 'db_export.php' . Url::getCommon(array('db' => $db));
+    $err_url = 'db_export.php' . Url::getCommon(['db' => $db]);
     // Check if we have something to export
     if (isset($table_select)) {
         $tables = $table_select;
     } else {
-        $tables = array();
+        $tables = [];
     }
 } elseif ($export_type == 'table' && strlen($db) > 0 && strlen($table) > 0) {
     $err_url = 'tbl_export.php' . Url::getCommon(
-        array(
-            'db' => $db, 'table' => $table
-        )
+        [
+            'db' => $db,
+            'table' => $table,
+        ]
     );
 } else {
     Core::fatalError(__('Bad parameters!'));
@@ -290,15 +315,15 @@ if ($export_type == 'server') {
 // Merge SQL Query aliases with Export aliases from
 // export page, Export page aliases are given more
 // preference over SQL Query aliases.
-$parser = new \PhpMyAdmin\SqlParser\Parser($sql_query);
-$aliases = array();
-if ((!empty($parser->statements[0]))
-    && ($parser->statements[0] instanceof \PhpMyAdmin\SqlParser\Statements\SelectStatement)
+$parser = new Parser($sql_query);
+$aliases = [];
+if (! empty($parser->statements[0])
+    && ($parser->statements[0] instanceof SelectStatement)
 ) {
-    $aliases = \PhpMyAdmin\SqlParser\Utils\Misc::getAliases($parser->statements[0], $db);
+    $aliases = Misc::getAliases($parser->statements[0], $db);
 }
-if (!empty($_POST['aliases'])) {
-    $aliases = Export::mergeAliases($aliases, $_POST['aliases']);
+if (! empty($_POST['aliases'])) {
+    $aliases = $export->mergeAliases($aliases, $_POST['aliases']);
     $_SESSION['tmpval']['aliases'] = $_POST['aliases'];
 }
 
@@ -309,13 +334,13 @@ Util::setTimeLimit();
 if (! empty($cfg['MemoryLimit'])) {
     ini_set('memory_limit', $cfg['MemoryLimit']);
 }
-register_shutdown_function('PhpMyAdmin\Export::shutdown');
+register_shutdown_function([$export, 'shutdown']);
 // Start with empty buffer
 $dump_buffer = '';
 $dump_buffer_len = 0;
 
 // Array of dump_buffers - used in separate file exports
-$dump_buffer_objects = array();
+$dump_buffer_objects = [];
 
 // We send fake headers to avoid browser timeout when buffering
 $time_start = time();
@@ -339,7 +364,7 @@ $output_charset_conversion = $asfile
 $GLOBALS['onfly_compression'] = $GLOBALS['cfg']['CompressOnFly']
     && $compression == 'gzip';
 if ($GLOBALS['onfly_compression']) {
-    $GLOBALS['memory_limit'] = Export::getMemoryLimit();
+    $GLOBALS['memory_limit'] = $export->getMemoryLimit();
 }
 
 // Generate filename and mime type if needed
@@ -347,8 +372,11 @@ if ($asfile) {
     if (empty($remember_template)) {
         $remember_template = '';
     }
-    list($filename, $mime_type) = Export::getFilenameAndMimetype(
-        $export_type, $remember_template, $export_plugin, $compression,
+    list($filename, $mime_type) = $export->getFilenameAndMimetype(
+        $export_type,
+        $remember_template,
+        $export_plugin,
+        $compression,
         $filename_template
     );
 } else {
@@ -357,13 +385,14 @@ if ($asfile) {
 
 // Open file on server if needed
 if ($save_on_server) {
-    list($save_filename, $message, $file_handle) = Export::openFile(
-        $filename, $quick_export
+    list($save_filename, $message, $file_handle) = $export->openFile(
+        $filename,
+        $quick_export
     );
 
     // problem opening export file on server?
     if (! empty($message)) {
-        Export::showPage($db, $table, $export_type);
+        $export->showPage($db, $table, $export_type);
     }
 } else {
     /**
@@ -382,24 +411,27 @@ if ($save_on_server) {
         // HTML
         if ($export_type == 'database') {
             $num_tables = count($tables);
-            if ($num_tables == 0) {
+            if ($num_tables === 0) {
                 $message = PhpMyAdmin\Message::error(
                     __('No tables found in database.')
                 );
                 $active_page = 'db_export.php';
-                include 'db_export.php';
-                exit();
+                include ROOT_PATH . 'db_export.php';
+                exit;
             }
         }
-        list($html, $back_button, $refreshButton) = Export::getHtmlForDisplayedExportHeader(
-            $export_type, $db, $table
+        list($html, $back_button, $refreshButton) = $export->getHtmlForDisplayedExportHeader(
+            $export_type,
+            $db,
+            $table
         );
         echo $html;
         unset($html);
     } // end download
 }
 
-$relation = new Relation();
+/** @var Relation $relation */
+$relation = $containerBuilder->get('relation');
 
 // Fake loop just to allow skip of remain of this code by break, I'd really
 // need exceptions here :-)
@@ -434,39 +466,71 @@ do {
         if (! isset($db_select)) {
             $db_select = '';
         }
-        Export::exportServer(
-            $db_select, $whatStrucOrData, $export_plugin, $crlf, $err_url,
-            $export_type, $do_relation, $do_comments, $do_mime, $do_dates,
-            $aliases, $separate_files
+        $export->exportServer(
+            $db_select,
+            $whatStrucOrData,
+            $export_plugin,
+            $crlf,
+            $err_url,
+            $export_type,
+            $do_relation,
+            $do_comments,
+            $do_mime,
+            $do_dates,
+            $aliases,
+            $separate_files
         );
     } elseif ($export_type == 'database') {
-        if (!isset($table_structure) || !is_array($table_structure)) {
-            $table_structure = array();
+        if (! isset($table_structure) || ! is_array($table_structure)) {
+            $table_structure = [];
         }
-        if (!isset($table_data) || !is_array($table_data)) {
-            $table_data = array();
+        if (! isset($table_data) || ! is_array($table_data)) {
+            $table_data = [];
         }
-        if (!empty($_POST['structure_or_data_forced'])) {
+        if (! empty($_POST['structure_or_data_forced'])) {
             $table_structure = $tables;
             $table_data = $tables;
         }
         if (isset($lock_tables)) {
-            Export::lockTables($db, $tables, "READ");
+            $export->lockTables($db, $tables, "READ");
             try {
-                Export::exportDatabase(
-                    $db, $tables, $whatStrucOrData, $table_structure,
-                    $table_data, $export_plugin, $crlf, $err_url, $export_type,
-                    $do_relation, $do_comments, $do_mime, $do_dates, $aliases,
+                $export->exportDatabase(
+                    $db,
+                    $tables,
+                    $whatStrucOrData,
+                    $table_structure,
+                    $table_data,
+                    $export_plugin,
+                    $crlf,
+                    $err_url,
+                    $export_type,
+                    $do_relation,
+                    $do_comments,
+                    $do_mime,
+                    $do_dates,
+                    $aliases,
                     $separate_files
                 );
             } finally {
-                Export::unlockTables();
+                $export->unlockTables();
             }
         } else {
-            Export::exportDatabase(
-                $db, $tables, $whatStrucOrData, $table_structure, $table_data,
-                $export_plugin, $crlf, $err_url, $export_type, $do_relation,
-                $do_comments, $do_mime, $do_dates, $aliases, $separate_files
+            $export->exportDatabase(
+                $db,
+                $tables,
+                $whatStrucOrData,
+                $table_structure,
+                $table_data,
+                $export_plugin,
+                $crlf,
+                $err_url,
+                $export_type,
+                $do_relation,
+                $do_comments,
+                $do_mime,
+                $do_dates,
+                $aliases,
+                $separate_files
             );
         }
     } else {
@@ -476,47 +540,71 @@ do {
             $allrows = '';
         }
         if (! isset($limit_to)) {
-            $limit_to = 0;
+            $limit_to = '0';
         }
         if (! isset($limit_from)) {
-            $limit_from = 0;
+            $limit_from = '0';
         }
         if (isset($lock_tables)) {
             try {
-                Export::lockTables($db, array($table), "READ");
-                Export::exportTable(
-                    $db, $table, $whatStrucOrData, $export_plugin, $crlf,
-                    $err_url, $export_type, $do_relation, $do_comments,
-                    $do_mime, $do_dates, $allrows, $limit_to, $limit_from,
-                    $sql_query, $aliases
+                $export->lockTables($db, [$table], "READ");
+                $export->exportTable(
+                    $db,
+                    $table,
+                    $whatStrucOrData,
+                    $export_plugin,
+                    $crlf,
+                    $err_url,
+                    $export_type,
+                    $do_relation,
+                    $do_comments,
+                    $do_mime,
+                    $do_dates,
+                    $allrows,
+                    $limit_to,
+                    $limit_from,
+                    $sql_query,
+                    $aliases
                 );
             } finally {
-                Export::unlockTables();
+                $export->unlockTables();
             }
         } else {
-            Export::exportTable(
-                $db, $table, $whatStrucOrData, $export_plugin, $crlf, $err_url,
-                $export_type, $do_relation, $do_comments, $do_mime, $do_dates,
-                $allrows, $limit_to, $limit_from, $sql_query, $aliases
+            $export->exportTable(
+                $db,
+                $table,
+                $whatStrucOrData,
+                $export_plugin,
+                $crlf,
+                $err_url,
+                $export_type,
+                $do_relation,
+                $do_comments,
+                $do_mime,
+                $do_dates,
+                $allrows,
+                $limit_to,
+                $limit_from,
+                $sql_query,
+                $aliases
             );
         }
     }
     if (! $export_plugin->exportFooter()) {
         break;
     }
-
 } while (false);
 // End of fake loop
 
 if ($save_on_server && ! empty($message)) {
-    Export::showPage($db, $table, $export_type);
+    $export->showPage($db, $table, $export_type);
 }
 
 /**
  * Send the dump as a file...
  */
 if (empty($asfile)) {
-    echo Export::getHtmlForDisplayedExportFooter($back_button, $refreshButton);
+    echo $export->getHtmlForDisplayedExportFooter($back_button, $refreshButton);
     return;
 } // end if
 
@@ -532,21 +620,24 @@ if ($output_charset_conversion) {
 // Compression needed?
 if ($compression) {
     if (! empty($separate_files)) {
-        $dump_buffer = Export::compress(
-            $dump_buffer_objects, $compression, $filename
+        $dump_buffer = $export->compress(
+            $dump_buffer_objects,
+            $compression,
+            $filename
         );
     } else {
-        $dump_buffer = Export::compress($dump_buffer, $compression, $filename);
+        $dump_buffer = $export->compress($dump_buffer, $compression, $filename);
     }
-
 }
 
 /* If we saved on server, we have to close file now */
 if ($save_on_server) {
-    $message = Export::closeFile(
-        $file_handle, $dump_buffer, $save_filename
+    $message = $export->closeFile(
+        $file_handle,
+        $dump_buffer,
+        $save_filename
     );
-    Export::showPage($db, $table, $export_type);
+    $export->showPage($db, $table, $export_type);
 } else {
     echo $dump_buffer;
 }
