@@ -5,9 +5,11 @@
  *
  * @package PhpMyAdmin
  */
+declare(strict_types=1);
 
 use PhpMyAdmin\Bookmark;
 use PhpMyAdmin\Core;
+use PhpMyAdmin\DatabaseInterface;
 use PhpMyAdmin\Encoding;
 use PhpMyAdmin\File;
 use PhpMyAdmin\Import;
@@ -19,15 +21,27 @@ use PhpMyAdmin\Sql;
 use PhpMyAdmin\Url;
 use PhpMyAdmin\Util;
 
+if (! defined('ROOT_PATH')) {
+    define('ROOT_PATH', __DIR__ . DIRECTORY_SEPARATOR);
+}
+
 /* Enable LOAD DATA LOCAL INFILE for LDI plugin */
 if (isset($_POST['format']) && $_POST['format'] == 'ldi') {
     define('PMA_ENABLE_LDI', 1);
 }
 
-/**
- * Get the variables sent or posted to this script and a core script
- */
-require_once 'libraries/common.inc.php';
+global $db, $pmaThemeImage, $table;
+
+require_once ROOT_PATH . 'libraries/common.inc.php';
+
+/** @var Response $response */
+$response = $containerBuilder->get(Response::class);
+
+/** @var DatabaseInterface $dbi */
+$dbi = $containerBuilder->get(DatabaseInterface::class);
+
+/** @var import $import */
+$import = $containerBuilder->get('import');
 
 if (isset($_POST['show_as_php'])) {
     $GLOBALS['show_as_php'] = $_POST['show_as_php'];
@@ -35,18 +49,17 @@ if (isset($_POST['show_as_php'])) {
 
 // If there is a request to 'Simulate DML'.
 if (isset($_POST['simulate_dml'])) {
-    Import::handleSimulateDmlRequest();
+    $import->handleSimulateDmlRequest();
     exit;
 }
 
-$response = Response::getInstance();
-
 $sql = new Sql();
 
 // If it's a refresh console bookmarks request
 if (isset($_GET['console_bookmark_refresh'])) {
     $response->addJSON(
-        'console_message_bookmark', PhpMyAdmin\Console::getBookmarkContent()
+        'console_message_bookmark',
+        PhpMyAdmin\Console::getBookmarkContent()
     );
     exit;
 }
@@ -56,15 +69,15 @@ if (isset($_POST['console_bookmark_add'])) {
         && isset($_POST['bookmark_query']) && isset($_POST['shared'])
     ) {
         $cfgBookmark = Bookmark::getParams($GLOBALS['cfg']['Server']['user']);
-        $bookmarkFields = array(
+        $bookmarkFields = [
             'bkm_database' => $_POST['db'],
             'bkm_user'  => $cfgBookmark['user'],
             'bkm_sql_query' => $_POST['bookmark_query'],
-            'bkm_label' => $_POST['label']
-        );
+            'bkm_label' => $_POST['label'],
+        ];
         $isShared = ($_POST['shared'] == 'true' ? true : false);
         $bookmark = Bookmark::createBookmark(
-            $GLOBALS['dbi'],
+            $dbi,
             $GLOBALS['cfg']['Server']['user'],
             $bookmarkFields,
             $isShared
@@ -88,7 +101,7 @@ $format = '';
 /**
  * Sets globals from $_POST
  */
-$post_params = array(
+$post_params = [
     'charset_of_file',
     'format',
     'import_type',
@@ -97,8 +110,8 @@ $post_params = array(
     'message_to_show',
     'noplugin',
     'skip_queries',
-    'local_import_file'
-);
+    'local_import_file',
+];
 
 foreach ($post_params as $one_post_param) {
     if (isset($_POST[$one_post_param])) {
@@ -114,15 +127,15 @@ $GLOBALS['reload'] = false;
 
 // Use to identify current cycle is executing
 // a multiquery statement or stored routine
-if (!isset($_SESSION['is_multi_query'])) {
+if (! isset($_SESSION['is_multi_query'])) {
     $_SESSION['is_multi_query'] = false;
 }
 
-$ajax_reload = array();
+$ajax_reload = [];
+$import_text = '';
 // Are we just executing plain query or sql file?
 // (eg. non import, but query box/window run)
 if (! empty($sql_query)) {
-
     // apply values for parameters
     if (! empty($_POST['parameterized'])
         && ! empty($_POST['parameters'])
@@ -134,13 +147,13 @@ if (! empty($sql_query)) {
             // making sure that :param does not apply values to :param1
             $sql_query = preg_replace(
                 '/' . $quoted . '([^a-zA-Z0-9_])/',
-                $GLOBALS['dbi']->escapeString($replacement) . '${1}',
+                $dbi->escapeString($replacement) . '${1}',
                 $sql_query
             );
             // for parameters the appear at the end of the string
             $sql_query = preg_replace(
                 '/' . $quoted . '$/',
-                $GLOBALS['dbi']->escapeString($replacement),
+                $dbi->escapeString($replacement),
                 $sql_query
             );
         }
@@ -154,7 +167,7 @@ if (! empty($sql_query)) {
 
     // If there is a request to ROLLBACK when finished.
     if (isset($_POST['rollback_query'])) {
-        Import::handleRollbackRequest($import_text);
+        $import->handleRollbackRequest($import_text);
     }
 
     // refresh navigation and main panels
@@ -199,7 +212,7 @@ if (! empty($sql_query)) {
 
 // If we didn't get any parameters, either user called this directly, or
 // upload limit has been reached, let's assume the second possibility.
-if ($_POST == array() && $_GET == array()) {
+if ($_POST == [] && $_GET == []) {
     $message = PhpMyAdmin\Message::error(
         __(
             'You probably tried to upload a file that is too large. Please refer ' .
@@ -231,15 +244,15 @@ if (isset($_POST['console_message_id'])) {
 
 if (! in_array(
     $format,
-    array(
+    [
         'csv',
         'ldi',
         'mediawiki',
         'ods',
         'shp',
         'sql',
-        'xml'
-    )
+        'xml',
+    ]
 )
 ) {
     // this should not happen for a normal user
@@ -247,25 +260,28 @@ if (! in_array(
     Core::fatalError('Incorrect format parameter');
 }
 
-$post_patterns = array(
+$post_patterns = [
     '/^force_file_/',
-    '/^' . $format . '_/'
-);
+    '/^' . $format . '_/',
+];
 
 Core::setPostAsGlobal($post_patterns);
 
 // Check needed parameters
-PhpMyAdmin\Util::checkParameters(array('import_type', 'format'));
+PhpMyAdmin\Util::checkParameters(['import_type', 'format']);
 
 // We don't want anything special in format
 $format = Core::securePath($format);
 
 if (strlen($table) > 0 && strlen($db) > 0) {
-    $urlparams = array('db' => $db, 'table' => $table);
+    $urlparams = [
+        'db' => $db,
+        'table' => $table,
+    ];
 } elseif (strlen($db) > 0) {
-    $urlparams = array('db' => $db);
+    $urlparams = ['db' => $db];
 } else {
-    $urlparams = array();
+    $urlparams = [];
 }
 
 // Create error and goto url
@@ -275,15 +291,13 @@ if ($import_type == 'table') {
     $goto = 'db_import.php';
 } elseif ($import_type == 'server') {
     $goto = 'server_import.php';
-} else {
-    if (empty($goto) || !preg_match('@^(server|db|tbl)(_[a-z]*)*\.php$@i', $goto)) {
-        if (strlen($table) > 0 && strlen($db) > 0) {
-            $goto = 'tbl_structure.php';
-        } elseif (strlen($db) > 0) {
-            $goto = 'db_structure.php';
-        } else {
-            $goto = 'server_sql.php';
-        }
+} elseif (empty($goto) || ! preg_match('@^(server|db|tbl)(_[a-z]*)*\.php$@i', $goto)) {
+    if (strlen($table) > 0 && strlen($db) > 0) {
+        $goto = 'tbl_structure.php';
+    } elseif (strlen($db) > 0) {
+        $goto = 'db_structure.php';
+    } else {
+        $goto = 'server_sql.php';
     }
 }
 $err_url = $goto . Url::getCommon($urlparams);
@@ -296,7 +310,7 @@ if (basename($_SERVER['SCRIPT_NAME']) === 'import.php') {
 
 
 if (strlen($db) > 0) {
-    $GLOBALS['dbi']->selectDb($db);
+    $dbi->selectDb($db);
 }
 
 Util::setTimeLimit();
@@ -332,88 +346,88 @@ $msg = 'Sorry an unexpected error happened!';
 
 // Bookmark Support: get a query back from bookmark if required
 if (! empty($_POST['id_bookmark'])) {
-    $id_bookmark = (int)$_POST['id_bookmark'];
+    $id_bookmark = (int) $_POST['id_bookmark'];
     switch ($_POST['action_bookmark']) {
-    case 0: // bookmarked query that have to be run
-        $bookmark = Bookmark::get(
-            $GLOBALS['dbi'],
-            $GLOBALS['cfg']['Server']['user'],
-            $db,
-            $id_bookmark,
-            'id',
-            isset($_POST['action_bookmark_all'])
-        );
-
-        if (! empty($_POST['bookmark_variable'])) {
-            $import_text = $bookmark->applyVariables(
-                $_POST['bookmark_variable']
+        case 0: // bookmarked query that have to be run
+            $bookmark = Bookmark::get(
+                $dbi,
+                $GLOBALS['cfg']['Server']['user'],
+                $db,
+                $id_bookmark,
+                'id',
+                isset($_POST['action_bookmark_all'])
             );
-        } else {
-            $import_text = $bookmark->getQuery();
-        }
 
-        // refresh navigation and main panels
-        if (preg_match(
-            '/^(DROP)\s+(VIEW|TABLE|DATABASE|SCHEMA)\s+/i',
-            $import_text
-        )) {
-            $GLOBALS['reload'] = true;
-            $ajax_reload['reload'] = true;
-        }
-
-        // refresh navigation panel only
-        if (preg_match(
-            '/^(CREATE|ALTER)\s+(VIEW|TABLE|DATABASE|SCHEMA)\s+/i',
-            $import_text
-        )
-        ) {
-            $ajax_reload['reload'] = true;
-        }
-        break;
-    case 1: // bookmarked query that have to be displayed
-        $bookmark = Bookmark::get(
-            $GLOBALS['dbi'],
-            $GLOBALS['cfg']['Server']['user'],
-            $db,
-            $id_bookmark
-        );
-        $import_text = $bookmark->getQuery();
-        if ($response->isAjax()) {
-            $message = PhpMyAdmin\Message::success(__('Showing bookmark'));
-            $response->setRequestStatus($message->isSuccess());
-            $response->addJSON('message', $message);
-            $response->addJSON('sql_query', $import_text);
-            $response->addJSON('action_bookmark', $_POST['action_bookmark']);
-            exit;
-        } else {
-            $run_query = false;
-        }
-        break;
-    case 2: // bookmarked query that have to be deleted
-        $bookmark = Bookmark::get(
-            $GLOBALS['dbi'],
-            $GLOBALS['cfg']['Server']['user'],
-            $db,
-            $id_bookmark
-        );
-        if (! empty($bookmark)) {
-            $bookmark->delete();
-            if ($response->isAjax()) {
-                $message = PhpMyAdmin\Message::success(
-                    __('The bookmark has been deleted.')
+            if (! empty($_POST['bookmark_variable'])) {
+                $import_text = $bookmark->applyVariables(
+                    $_POST['bookmark_variable']
                 );
+            } else {
+                $import_text = $bookmark->getQuery();
+            }
+
+            // refresh navigation and main panels
+            if (preg_match(
+                '/^(DROP)\s+(VIEW|TABLE|DATABASE|SCHEMA)\s+/i',
+                $import_text
+            )) {
+                $GLOBALS['reload'] = true;
+                $ajax_reload['reload'] = true;
+            }
+
+            // refresh navigation panel only
+            if (preg_match(
+                '/^(CREATE|ALTER)\s+(VIEW|TABLE|DATABASE|SCHEMA)\s+/i',
+                $import_text
+            )
+            ) {
+                $ajax_reload['reload'] = true;
+            }
+            break;
+        case 1: // bookmarked query that have to be displayed
+            $bookmark = Bookmark::get(
+                $dbi,
+                $GLOBALS['cfg']['Server']['user'],
+                $db,
+                $id_bookmark
+            );
+            $import_text = $bookmark->getQuery();
+            if ($response->isAjax()) {
+                $message = PhpMyAdmin\Message::success(__('Showing bookmark'));
                 $response->setRequestStatus($message->isSuccess());
                 $response->addJSON('message', $message);
+                $response->addJSON('sql_query', $import_text);
                 $response->addJSON('action_bookmark', $_POST['action_bookmark']);
-                $response->addJSON('id_bookmark', $id_bookmark);
                 exit;
             } else {
                 $run_query = false;
-                $error = true; // this is kind of hack to skip processing the query
             }
-        }
+            break;
+        case 2: // bookmarked query that have to be deleted
+            $bookmark = Bookmark::get(
+                $dbi,
+                $GLOBALS['cfg']['Server']['user'],
+                $db,
+                $id_bookmark
+            );
+            if (! empty($bookmark)) {
+                $bookmark->delete();
+                if ($response->isAjax()) {
+                    $message = PhpMyAdmin\Message::success(
+                        __('The bookmark has been deleted.')
+                    );
+                    $response->setRequestStatus($message->isSuccess());
+                    $response->addJSON('message', $message);
+                    $response->addJSON('action_bookmark', $_POST['action_bookmark']);
+                    $response->addJSON('id_bookmark', $id_bookmark);
+                    exit;
+                } else {
+                    $run_query = false;
+                    $error = true; // this is kind of hack to skip processing the query
+                }
+            }
 
-        break;
+            break;
     }
 } // end bookmarks reading
 
@@ -435,15 +449,15 @@ if ($memory_limit == -1) {
 }
 
 // Calculate value of the limit
-$memoryUnit = mb_strtolower(substr($memory_limit, -1));
+$memoryUnit = mb_strtolower(substr((string) $memory_limit, -1));
 if ('m' == $memoryUnit) {
-    $memory_limit = (int)substr($memory_limit, 0, -1) * 1024 * 1024;
+    $memory_limit = (int) substr((string) $memory_limit, 0, -1) * 1024 * 1024;
 } elseif ('k' == $memoryUnit) {
-    $memory_limit = (int)substr($memory_limit, 0, -1) * 1024;
+    $memory_limit = (int) substr((string) $memory_limit, 0, -1) * 1024;
 } elseif ('g' == $memoryUnit) {
-    $memory_limit = (int)substr($memory_limit, 0, -1) * 1024 * 1024 * 1024;
+    $memory_limit = (int) substr((string) $memory_limit, 0, -1) * 1024 * 1024 * 1024;
 } else {
-    $memory_limit = (int)$memory_limit;
+    $memory_limit = (int) $memory_limit;
 }
 
 // Just to be sure, there might be lot of memory needed for uncompression
@@ -452,9 +466,9 @@ $read_limit = $memory_limit / 8;
 // handle filenames
 if (isset($_FILES['import_file'])) {
     $import_file = $_FILES['import_file']['tmp_name'];
+    $import_file_name = $_FILES['import_file']['name'];
 }
 if (! empty($local_import_file) && ! empty($cfg['UploadDir'])) {
-
     // sanitize $local_import_file as it comes from a POST
     $local_import_file = Core::securePath($local_import_file);
 
@@ -469,7 +483,6 @@ if (! empty($local_import_file) && ! empty($cfg['UploadDir'])) {
     if (@is_link($import_file)) {
         $import_file  = 'none';
     }
-
 } elseif (empty($import_file) || ! is_uploaded_file($import_file)) {
     $import_file  = 'none';
 }
@@ -483,12 +496,12 @@ if ($import_file != 'none' && ! $error) {
     $import_handle = new File($import_file);
     $import_handle->checkUploadedFile();
     if ($import_handle->isError()) {
-        Import::stop($import_handle->getError());
+        $import->stop($import_handle->getError());
     }
     $import_handle->setDecompressContent(true);
     $import_handle->open();
     if ($import_handle->isError()) {
-        Import::stop($import_handle->getError());
+        $import->stop($import_handle->getError());
     }
 } elseif (! $error) {
     if (! isset($import_text) || empty($import_text)) {
@@ -499,7 +512,7 @@ if ($import_file != 'none' && ! $error) {
                 'by your PHP configuration. See [doc@faq1-16]FAQ 1.16[/doc].'
             )
         );
-        Import::stop($message);
+        $import->stop($message);
     }
 }
 
@@ -512,7 +525,7 @@ if (Encoding::isSupported() && isset($charset_of_file)) {
         $charset_conversion = true;
     }
 } elseif (isset($charset_of_file) && $charset_of_file != 'utf-8') {
-    $GLOBALS['dbi']->query('SET NAMES \'' . $charset_of_file . '\'');
+    $dbi->query('SET NAMES \'' . $charset_of_file . '\'');
     // We can not show query in this case, it is in different charset
     $sql_query_disabled = true;
     $reset_charset = true;
@@ -522,7 +535,7 @@ if (Encoding::isSupported() && isset($charset_of_file)) {
 if (! $error && isset($_POST['skip'])) {
     $original_skip = $skip = intval($_POST['skip']);
     while ($skip > 0 && ! $finished) {
-        Import::getNextChunk($skip < $read_limit ? $skip : $read_limit);
+        $import->getNextChunk($skip < $read_limit ? $skip : $read_limit);
         // Disable read progressivity, otherwise we eat all memory!
         $read_multiply = 1;
         $skip -= $read_limit;
@@ -532,10 +545,15 @@ if (! $error && isset($_POST['skip'])) {
 
 // This array contain the data like numberof valid sql queries in the statement
 // and complete valid sql statement (which affected for rows)
-$sql_data = array('valid_sql' => array(), 'valid_queries' => 0);
+$sql_data = [
+    'valid_sql' => [],
+    'valid_queries' => 0,
+];
 
 if (! $error) {
-    /* @var $import_plugin ImportPlugin */
+    /**
+     * @var ImportPlugin $import_plugin
+     */
     $import_plugin = Plugins::getPlugin(
         "import",
         $format,
@@ -546,11 +564,11 @@ if (! $error) {
         $message = PhpMyAdmin\Message::error(
             __('Could not load import plugins, please check your installation!')
         );
-        Import::stop($message);
+        $import->stop($message);
     } else {
         // Do the real import
+        $default_fk_check = PhpMyAdmin\Util::handleDisableFKCheckInit();
         try {
-            $default_fk_check = PhpMyAdmin\Util::handleDisableFKCheckInit();
             $import_plugin->doImport($sql_data);
             PhpMyAdmin\Util::handleDisableFKCheckCleanup($default_fk_check);
         } catch (Exception $e) {
@@ -571,8 +589,8 @@ if ($file_to_unlink != '') {
 
 // Reset charset back, if we did some changes
 if ($reset_charset) {
-    $GLOBALS['dbi']->query('SET CHARACTER SET ' . $GLOBALS['charset_connection']);
-    $GLOBALS['dbi']->setCollationConnection($collation_connection);
+    $dbi->query('SET CHARACTER SET ' . $GLOBALS['charset_connection']);
+    $dbi->setCollation($collation_connection);
 }
 
 // Show correct message
@@ -583,7 +601,7 @@ if (! empty($id_bookmark) && $_POST['action_bookmark'] == 2) {
 } elseif (! empty($id_bookmark) && $_POST['action_bookmark'] == 1) {
     $message = PhpMyAdmin\Message::notice(__('Showing bookmark'));
 } elseif ($bookmark_created) {
-    $special_message = '[br]'  . sprintf(
+    $special_message = '[br]' . sprintf(
         __('Bookmark %s has been created.'),
         htmlspecialchars($_POST['bkm_label'])
     );
@@ -662,7 +680,7 @@ if ($sqlLength <= $GLOBALS['cfg']['MaxCharactersInDisplayedSQL']) {
     // @todo: possibly refactor
     extract($analyzed_sql_results);
 
-    if ($table != $table_from_sql && !empty($table_from_sql)) {
+    if ($table != $table_from_sql && ! empty($table_from_sql)) {
         $table = $table_from_sql;
     }
 }
@@ -671,24 +689,26 @@ if ($sqlLength <= $GLOBALS['cfg']['MaxCharactersInDisplayedSQL']) {
 if (isset($my_die)) {
     foreach ($my_die as $key => $die) {
         PhpMyAdmin\Util::mysqlDie(
-            $die['error'], $die['sql'], false, $err_url, $error
+            $die['error'],
+            $die['sql'],
+            false,
+            $err_url,
+            $error
         );
     }
 }
 
 if ($go_sql) {
-
     if (! empty($sql_data) && ($sql_data['valid_queries'] > 1)) {
         $_SESSION['is_multi_query'] = true;
         $sql_queries = $sql_data['valid_sql'];
     } else {
-        $sql_queries = array($sql_query);
+        $sql_queries = [$sql_query];
     }
 
     $html_output = '';
 
     foreach ($sql_queries as $sql_query) {
-
         // parse sql query
         list(
             $analyzed_sql_results,
@@ -700,7 +720,9 @@ if ($go_sql) {
 
         // Check if User is allowed to issue a 'DROP DATABASE' Statement
         if ($sql->hasNoRightsToDropDatabase(
-            $analyzed_sql_results, $cfg['AllowUserDropDatabase'], $GLOBALS['dbi']->isSuperuser()
+            $analyzed_sql_results,
+            $cfg['AllowUserDropDatabase'],
+            $dbi->isSuperuser()
         )) {
             PhpMyAdmin\Util::mysqlDie(
                 __('"DROP DATABASE" statements are disabled.'),
@@ -711,7 +733,7 @@ if ($go_sql) {
             return;
         } // end if
 
-        if ($table != $table_from_sql && !empty($table_from_sql)) {
+        if ($table != $table_from_sql && ! empty($table_from_sql)) {
             $table = $table_from_sql;
         }
 
@@ -743,23 +765,26 @@ if ($go_sql) {
     if (! empty($_POST['bkm_label']) && ! empty($import_text)) {
         $cfgBookmark = Bookmark::getParams($GLOBALS['cfg']['Server']['user']);
         $sql->storeTheQueryAsBookmark(
-            $db, $cfgBookmark['user'],
-            $_POST['sql_query'], $_POST['bkm_label'],
+            $db,
+            $cfgBookmark['user'],
+            $_POST['sql_query'],
+            $_POST['bkm_label'],
             isset($_POST['bkm_replace']) ? $_POST['bkm_replace'] : null
         );
     }
 
     $response->addJSON('ajax_reload', $ajax_reload);
     $response->addHTML($html_output);
-    exit();
-
+    exit;
 } elseif ($result) {
     // Save a Bookmark with more than one queries (if Bookmark label given).
     if (! empty($_POST['bkm_label']) && ! empty($import_text)) {
         $cfgBookmark = Bookmark::getParams($GLOBALS['cfg']['Server']['user']);
         $sql->storeTheQueryAsBookmark(
-            $db, $cfgBookmark['user'],
-            $_POST['sql_query'], $_POST['bkm_label'],
+            $db,
+            $cfgBookmark['user'],
+            $_POST['sql_query'],
+            $_POST['bkm_label'],
             isset($_POST['bkm_replace']) ? $_POST['bkm_replace'] : null
         );
     }
@@ -770,15 +795,15 @@ if ($go_sql) {
         'sql_query',
         PhpMyAdmin\Util::getMessage($msg, $sql_query, 'success')
     );
-} elseif ($result == false) {
+} elseif ($result === false) {
     $response->setRequestStatus(false);
     $response->addJSON('message', PhpMyAdmin\Message::error($msg));
 } else {
     $active_page = $goto;
-    include '' . $goto;
+    include ROOT_PATH . $goto;
 }
 
 // If there is request for ROLLBACK in the end.
 if (isset($_POST['rollback_query'])) {
-    $GLOBALS['dbi']->query('ROLLBACK');
+    $dbi->query('ROLLBACK');
 }
