@@ -13,7 +13,7 @@ var RTE = {
      * Construct for the object that provides the
      * functionality for Routines, Triggers and Events
      */
-    object: function (type) {
+    Object: function (type) {
         $.extend(this, RTE.COMMON);
         this.editorType = type;
 
@@ -31,10 +31,11 @@ var RTE = {
             break;
         }
     },
+
     /**
-     * @var string param_template Template for a row in the routine editor
+     * @var {string} paramTemplate Template for a row in the routine editor
      */
-    param_template: ''
+    paramTemplate: ''
 };
 
 /**
@@ -77,8 +78,8 @@ RTE.COMMON = {
         // and the definition must be provided for an item
         $elm = $('table.rte_table').last().find('input[name=item_name]');
         if ($elm.val() === '') {
-            $elm.focus();
-            alert(PMA_messages.strFormEmpty);
+            $elm.trigger('focus');
+            alert(Messages.strFormEmpty);
             return false;
         }
         $elm = $('table.rte_table').find('textarea[name=item_definition]');
@@ -86,9 +87,9 @@ RTE.COMMON = {
             if (this.syntaxHiglighter !== null) {
                 this.syntaxHiglighter.focus();
             } else {
-                $('textarea[name=item_definition]').last().focus();
+                $('textarea[name=item_definition]').last().trigger('focus');
             }
-            alert(PMA_messages.strFormEmpty);
+            alert(Messages.strFormEmpty);
             return false;
         }
         // The validation has so far passed, so now
@@ -114,25 +115,25 @@ RTE.COMMON = {
     }, // end postDialogShow()
 
     exportDialog: function ($this) {
-        var $msg = PMA_ajaxShowMessage();
+        var $msg = Functions.ajaxShowMessage();
         if ($this.hasClass('mult_submit')) {
             var combined = {
                 success: true,
-                title: PMA_messages.strExport,
+                title: Messages.strExport,
                 message: '',
                 error: ''
             };
             // export anchors of all selected rows
-            var export_anchors = $('input.checkall:checked').parents('tr').find('.export_anchor');
-            var count = export_anchors.length;
+            var exportAnchors = $('input.checkall:checked').parents('tr').find('.export_anchor');
+            var count = exportAnchors.length;
             var returnCount = 0;
 
             // No routine is exportable (due to privilege issues)
             if (count === 0) {
-                PMA_ajaxShowMessage(PMA_messages.NoExportable);
+                Functions.ajaxShowMessage(Messages.NoExportable);
             }
 
-            export_anchors.each(function () {
+            exportAnchors.each(function () {
                 $.get($(this).attr('href'), { 'ajax_request': true }, function (data) {
                     returnCount++;
                     if (data.success === true) {
@@ -153,17 +154,17 @@ RTE.COMMON = {
         } else {
             $.get($this.attr('href'), { 'ajax_request': true }, showExport);
         }
-        PMA_ajaxRemoveMessage($msg);
+        Functions.ajaxRemoveMessage($msg);
 
         function showExport (data) {
             if (data.success === true) {
-                PMA_ajaxRemoveMessage($msg);
+                Functions.ajaxRemoveMessage($msg);
                 /**
                  * @var button_options Object containing options
                  *                     for jQueryUI dialog buttons
                  */
-                var button_options = {};
-                button_options[PMA_messages.strClose] = function () {
+                var buttonOptions = {};
+                buttonOptions[Messages.strClose] = function () {
                     $(this).dialog('close').remove();
                 };
                 /**
@@ -172,7 +173,7 @@ RTE.COMMON = {
                 data.message = '<textarea cols="40" rows="15" class="all100">' + data.message + '</textarea>';
                 var $ajaxDialog = $('<div>' + data.message + '</div>').dialog({
                     width: 500,
-                    buttons: button_options,
+                    buttons: buttonOptions,
                     title: data.title
                 });
                 // Attach syntax highlighted editor to export dialog
@@ -181,38 +182,38 @@ RTE.COMMON = {
                  *           to the Export textarea.
                  */
                 var $elm = $ajaxDialog.find('textarea');
-                PMA_getSQLEditor($elm);
+                Functions.getSqlEditor($elm);
             } else {
-                PMA_ajaxShowMessage(data.error, false);
+                Functions.ajaxShowMessage(data.error, false);
             }
         } // end showExport()
     },  // end exportDialog()
-    editorDialog: function (is_new, $this) {
+    editorDialog: function (isNew, $this) {
         var that = this;
         /**
          * @var $edit_row jQuery object containing the reference to
          *                the row of the the item being edited
          *                from the list of items
          */
-        var $edit_row = null;
+        var $editRow = null;
         if ($this.hasClass('edit_anchor')) {
             // Remeber the row of the item being edited for later,
             // so that if the edit is successful, we can replace the
             // row with info about the modified item.
-            $edit_row = $this.parents('tr');
+            $editRow = $this.parents('tr');
         }
         /**
          * @var $msg jQuery object containing the reference to
          *           the AJAX message shown to the user
          */
-        var $msg = PMA_ajaxShowMessage();
+        var $msg = Functions.ajaxShowMessage();
         $.get($this.attr('href'), { 'ajax_request': true }, function (data) {
             if (data.success === true) {
                 // We have successfully fetched the editor form
-                PMA_ajaxRemoveMessage($msg);
+                Functions.ajaxRemoveMessage($msg);
                 // Now define the function that is called when
                 // the user presses the "Go" button
-                that.buttonOptions[PMA_messages.strGo] = function () {
+                that.buttonOptions[Messages.strGo] = function () {
                     // Move the data from the codemirror editor back to the
                     // textarea, where it can be used in the form submission.
                     if (typeof CodeMirror !== 'undefined') {
@@ -224,20 +225,20 @@ RTE.COMMON = {
                          * @var data Form data to be sent in the AJAX request
                          */
                         var data = $('form.rte_form').last().serialize();
-                        $msg = PMA_ajaxShowMessage(
-                            PMA_messages.strProcessingRequest
+                        $msg = Functions.ajaxShowMessage(
+                            Messages.strProcessingRequest
                         );
                         var url = $('form.rte_form').last().attr('action');
                         $.post(url, data, function (data) {
                             if (data.success === true) {
                                 // Item created successfully
-                                PMA_ajaxRemoveMessage($msg);
-                                PMA_slidingMessage(data.message);
+                                Functions.ajaxRemoveMessage($msg);
+                                Functions.slidingMessage(data.message);
                                 that.$ajaxDialog.dialog('close');
                                 // If we are in 'edit' mode, we must
                                 // remove the reference to the old row.
-                                if (mode === 'edit' && $edit_row !== null) {
-                                    $edit_row.remove();
+                                if (mode === 'edit' && $editRow !== null) {
+                                    $editRow.remove();
                                 }
                                 // Sometimes, like when moving a trigger from
                                 // a table to another one, the new row should
@@ -320,14 +321,14 @@ RTE.COMMON = {
                                         $('table.data').show('slow');
                                     });
                                 }
-                                PMA_reloadNavigation();
+                                Navigation.reload();
                             } else {
-                                PMA_ajaxShowMessage(data.error, false);
+                                Functions.ajaxShowMessage(data.error, false);
                             }
                         }); // end $.post()
                     } // end "if (that.validate())"
                 }; // end of function that handles the submission of the Editor
-                that.buttonOptions[PMA_messages.strClose] = function () {
+                that.buttonOptions[Messages.strClose] = function () {
                     $(this).dialog('close');
                 };
                 /**
@@ -344,12 +345,12 @@ RTE.COMMON = {
                         if ($('#rteDialog').parents('.ui-dialog').height() > $(window).height()) {
                             $('#rteDialog').dialog('option', 'height', $(window).height());
                         }
-                        $(this).find('input[name=item_name]').focus();
+                        $(this).find('input[name=item_name]').trigger('focus');
                         $(this).find('input.datefield').each(function () {
-                            PMA_addDatepicker($(this).css('width', '95%'), 'date');
+                            Functions.addDatepicker($(this).css('width', '95%'), 'date');
                         });
                         $(this).find('input.datetimefield').each(function () {
-                            PMA_addDatepicker($(this).css('width', '95%'), 'datetime');
+                            Functions.addDatepicker($(this).css('width', '95%'), 'datetime');
                         });
                         $.datepicker.initialized = false;
                     },
@@ -373,12 +374,12 @@ RTE.COMMON = {
                 var $elm = $('textarea[name=item_definition]').last();
                 var linterOptions = {};
                 linterOptions[that.editorType + '_editor'] = true;
-                that.syntaxHiglighter = PMA_getSQLEditor($elm, {}, null, linterOptions);
+                that.syntaxHiglighter = Functions.getSqlEditor($elm, {}, null, linterOptions);
 
                 // Execute item-specific code
                 that.postDialogShow(data);
             } else {
-                PMA_ajaxShowMessage(data.error, false);
+                Functions.ajaxShowMessage(data.error, false);
             }
         }); // end $.get()
     },
@@ -387,28 +388,28 @@ RTE.COMMON = {
         /**
          * @var $curr_row Object containing reference to the current row
          */
-        var $curr_row = $this.parents('tr');
+        var $currRow = $this.parents('tr');
         /**
          * @var question String containing the question to be asked for confirmation
          */
-        var question = $('<div/>').text(
-            $curr_row.children('td').children('.drop_sql').html()
+        var question = $('<div></div>').text(
+            $currRow.children('td').children('.drop_sql').html()
         );
         // We ask for confirmation first here, before submitting the ajax request
-        $this.PMA_confirm(question, $this.attr('href'), function (url) {
+        $this.confirm(question, $this.attr('href'), function (url) {
             /**
              * @var msg jQuery object containing the reference to
              *          the AJAX message shown to the user
              */
-            var $msg = PMA_ajaxShowMessage(PMA_messages.strProcessingRequest);
-            var params = getJSConfirmCommonParam(this, $this.getPostData());
+            var $msg = Functions.ajaxShowMessage(Messages.strProcessingRequest);
+            var params = Functions.getJsConfirmCommonParam(this, $this.getPostData());
             $.post(url, params, function (data) {
                 if (data.success === true) {
                     /**
                      * @var $table Object containing reference
                      *             to the main list of elements
                      */
-                    var $table = $curr_row.parent();
+                    var $table = $currRow.parent();
                     // Check how many rows will be left after we remove
                     // the one that the user has requested us to remove
                     if ($table.find('tr').length === 3) {
@@ -422,7 +423,7 @@ RTE.COMMON = {
                             $('#nothing2display').show('slow');
                         });
                     } else {
-                        $curr_row.hide('slow', function () {
+                        $currRow.hide('slow', function () {
                             $(this).remove();
                             // Now we have removed the row from the list, but maybe
                             // some row classes are wrong now. So we will itirate
@@ -444,39 +445,39 @@ RTE.COMMON = {
                         });
                     }
                     // Get rid of the "Loading" message
-                    PMA_ajaxRemoveMessage($msg);
+                    Functions.ajaxRemoveMessage($msg);
                     // Show the query that we just executed
-                    PMA_slidingMessage(data.sql_query);
-                    PMA_reloadNavigation();
+                    Functions.slidingMessage(data.sql_query);
+                    Navigation.reload();
                 } else {
-                    PMA_ajaxShowMessage(data.error, false);
+                    Functions.ajaxShowMessage(data.error, false);
                 }
             }); // end $.post()
-        }); // end $.PMA_confirm()
+        });
     },
 
     dropMultipleDialog: function ($this) {
         // We ask for confirmation here
-        $this.PMA_confirm(PMA_messages.strDropRTEitems, '', function (url) {
+        $this.confirm(Messages.strDropRTEitems, '', function () {
             /**
              * @var msg jQuery object containing the reference to
              *          the AJAX message shown to the user
              */
-            var $msg = PMA_ajaxShowMessage(PMA_messages.strProcessingRequest);
+            var $msg = Functions.ajaxShowMessage(Messages.strProcessingRequest);
 
             // drop anchors of all selected rows
-            var drop_anchors = $('input.checkall:checked').parents('tr').find('.drop_anchor');
+            var dropAnchors = $('input.checkall:checked').parents('tr').find('.drop_anchor');
             var success = true;
-            var count = drop_anchors.length;
+            var count = dropAnchors.length;
             var returnCount = 0;
 
-            drop_anchors.each(function () {
+            dropAnchors.each(function () {
                 var $anchor = $(this);
                 /**
                  * @var $curr_row Object containing reference to the current row
                  */
-                var $curr_row = $anchor.parents('tr');
-                var params = getJSConfirmCommonParam(this, $anchor.getPostData());
+                var $currRow = $anchor.parents('tr');
+                var params = Functions.getJsConfirmCommonParam(this, $anchor.getPostData());
                 $.post($anchor.attr('href'), params, function (data) {
                     returnCount++;
                     if (data.success === true) {
@@ -484,7 +485,7 @@ RTE.COMMON = {
                          * @var $table Object containing reference
                          *             to the main list of elements
                          */
-                        var $table = $curr_row.parent();
+                        var $table = $currRow.parent();
                         // Check how many rows will be left after we remove
                         // the one that the user has requested us to remove
                         if ($table.find('tr').length === 3) {
@@ -498,7 +499,7 @@ RTE.COMMON = {
                                 $('#nothing2display').show('slow');
                             });
                         } else {
-                            $curr_row.hide('fast', function () {
+                            $currRow.hide('fast', function () {
                                 $(this).remove();
                                 // Now we have removed the row from the list, but maybe
                                 // some row classes are wrong now. So we will itirate
@@ -522,21 +523,21 @@ RTE.COMMON = {
                         if (returnCount === count) {
                             if (success) {
                                 // Get rid of the "Loading" message
-                                PMA_ajaxRemoveMessage($msg);
+                                Functions.ajaxRemoveMessage($msg);
                                 $('#rteListForm_checkall').prop({ checked: false, indeterminate: false });
                             }
-                            PMA_reloadNavigation();
+                            Navigation.reload();
                         }
                     } else {
-                        PMA_ajaxShowMessage(data.error, false);
+                        Functions.ajaxShowMessage(data.error, false);
                         success = false;
                         if (returnCount === count) {
-                            PMA_reloadNavigation();
+                            Navigation.reload();
                         }
                     }
                 }); // end $.post()
             }); // end drop_anchors.each()
-        }); // end $.PMA_confirm()
+        });
     }
 }; // end RTE namespace
 
@@ -554,16 +555,16 @@ RTE.EVENT = {
             // The interval field must not be empty for recurring events
             $elm = this.$ajaxDialog.find('input[name=item_interval_value]');
             if ($elm.val() === '') {
-                $elm.focus();
-                alert(PMA_messages.strFormEmpty);
+                $elm.trigger('focus');
+                alert(Messages.strFormEmpty);
                 return false;
             }
         } else {
             // The execute_at field must not be empty for "once off" events
             $elm = this.$ajaxDialog.find('input[name=item_execute_at]');
             if ($elm.val() === '') {
-                $elm.focus();
-                alert(PMA_messages.strFormEmpty);
+                $elm.trigger('focus');
+                alert(Messages.strFormEmpty);
                 return false;
             }
         }
@@ -582,7 +583,7 @@ RTE.ROUTINE = {
      */
     postDialogShow: function (data) {
         // Cache the template for a parameter table row
-        RTE.param_template = data.param_template;
+        RTE.paramTemplate = data.paramTemplate;
         var that = this;
         // Make adjustments in the dialog to make it AJAX compatible
         $('td.routine_param_remove').show();
@@ -610,7 +611,7 @@ RTE.ROUTINE = {
         $('.routine_params_table tbody').sortable({
             containment: '.routine_params_table tbody',
             handle: '.dragHandle',
-            stop: function (event, ui) {
+            stop: function () {
                 that.reindexParameters();
             },
         });
@@ -672,7 +673,7 @@ RTE.ROUTINE = {
                         inputname.substr(0, 15) === 'item_param_name' ||
                         inputname.substr(0, 15) === 'item_param_type') {
                         if ($(this).val() === '') {
-                            $(this).focus();
+                            $(this).trigger('focus');
                             isSuccess = false;
                             return false;
                         }
@@ -683,7 +684,7 @@ RTE.ROUTINE = {
             }
         });
         if (! isSuccess) {
-            alert(PMA_messages.strFormEmpty);
+            alert(Messages.strFormEmpty);
             return false;
         }
         this.$ajaxDialog.find('table.routine_params_table').last().find('tr').each(function () {
@@ -694,14 +695,14 @@ RTE.ROUTINE = {
                 if (($inputtyp.val() === 'ENUM' || $inputtyp.val() === 'SET' || $inputtyp.val().substr(0, 3) === 'VAR') &&
                     $inputlen.val() === ''
                 ) {
-                    $inputlen.focus();
+                    $inputlen.trigger('focus');
                     isSuccess = false;
                     return false;
                 }
             }
         });
         if (! isSuccess) {
-            alert(PMA_messages.strFormEmpty);
+            alert(Messages.strFormEmpty);
             return false;
         }
         if (this.$ajaxDialog.find('select[name=item_type]').find(':selected').val() === 'FUNCTION') {
@@ -712,8 +713,8 @@ RTE.ROUTINE = {
             if (($returntyp.val() === 'ENUM' || $returntyp.val() === 'SET' || $returntyp.val().substr(0, 3) === 'VAR') &&
                 $returnlen.val() === ''
             ) {
-                $returnlen.focus();
-                alert(PMA_messages.strFormEmpty);
+                $returnlen.trigger('focus');
+                alert(Messages.strFormEmpty);
                 return false;
             }
         }
@@ -721,7 +722,7 @@ RTE.ROUTINE = {
             // A function must contain a RETURN statement in its definition
             if (this.$ajaxDialog.find('table.rte_table').find('textarea[name=item_definition]').val().toUpperCase().indexOf('RETURN') < 0) {
                 this.syntaxHiglighter.focus();
-                alert(PMA_messages.MissingReturn);
+                alert(Messages.MissingReturn);
                 return false;
             }
         }
@@ -749,13 +750,13 @@ RTE.ROUTINE = {
          *              to an element to be displayed when no
          *              options are available
          */
-        var $no_opts = $text.parent().parent().find('.no_opts');
+        var $noOpts = $text.parent().parent().find('.no_opts');
         /**
          * @var no_len a jQuery object containing the reference
          *             to an element to be displayed when no
          *             "length/values" field is available
          */
-        var $no_len  = $len.parent().parent().find('.no_len');
+        var $noLen  = $len.parent().parent().find('.no_len');
 
         // Process for parameter options
         switch ($type.val()) {
@@ -770,7 +771,7 @@ RTE.ROUTINE = {
         case 'REAL':
             $text.parent().hide();
             $num.parent().show();
-            $no_opts.hide();
+            $noOpts.hide();
             break;
         case 'TINYTEXT':
         case 'TEXT':
@@ -782,12 +783,12 @@ RTE.ROUTINE = {
         case 'ENUM':
             $text.parent().show();
             $num.parent().hide();
-            $no_opts.hide();
+            $noOpts.hide();
             break;
         default:
             $text.parent().hide();
             $num.parent().hide();
-            $no_opts.show();
+            $noOpts.show();
             break;
         }
         // Process for parameter length
@@ -803,7 +804,7 @@ RTE.ROUTINE = {
         case 'LONGTEXT':
             $text.closest('tr').find('a:first').hide();
             $len.parent().hide();
-            $no_len.show();
+            $noLen.show();
             break;
         default:
             if ($type.val() === 'ENUM' || $type.val() === 'SET') {
@@ -812,7 +813,7 @@ RTE.ROUTINE = {
                 $text.closest('tr').find('a:first').hide();
             }
             $len.parent().show();
-            $no_len.hide();
+            $noLen.hide();
             break;
         }
     },
@@ -822,39 +823,37 @@ RTE.ROUTINE = {
          * @var msg jQuery object containing the reference to
          *          the AJAX message shown to the user
          */
-        var $msg = PMA_ajaxShowMessage();
-        var params = {
-            'ajax_request': true
-        };
+        var $msg = Functions.ajaxShowMessage();
+        var params = Functions.getJsConfirmCommonParam($this[0], $this.getPostData());
         $.post($this.attr('href'), params, function (data) {
             if (data.success === true) {
-                PMA_ajaxRemoveMessage($msg);
+                Functions.ajaxRemoveMessage($msg);
                 // If 'data.dialog' is true we show a dialog with a form
                 // to get the input parameters for routine, otherwise
                 // we just show the results of the query
                 if (data.dialog) {
                     // Define the function that is called when
                     // the user presses the "Go" button
-                    that.buttonOptions[PMA_messages.strGo] = function () {
+                    that.buttonOptions[Messages.strGo] = function () {
                         /**
                          * @var data Form data to be sent in the AJAX request
                          */
                         var data = $('form.rte_form').last().serialize();
-                        $msg = PMA_ajaxShowMessage(
-                            PMA_messages.strProcessingRequest
+                        $msg = Functions.ajaxShowMessage(
+                            Messages.strProcessingRequest
                         );
                         $.post('db_routines.php', data, function (data) {
                             if (data.success === true) {
                                 // Routine executed successfully
-                                PMA_ajaxRemoveMessage($msg);
-                                PMA_slidingMessage(data.message);
+                                Functions.ajaxRemoveMessage($msg);
+                                Functions.slidingMessage(data.message);
                                 $ajaxDialog.dialog('close');
                             } else {
-                                PMA_ajaxShowMessage(data.error, false);
+                                Functions.ajaxShowMessage(data.error, false);
                             }
                         });
                     };
-                    that.buttonOptions[PMA_messages.strClose] = function () {
+                    that.buttonOptions[Messages.strClose] = function () {
                         $(this).dialog('close');
                     };
                     /**
@@ -869,12 +868,12 @@ RTE.ROUTINE = {
                             $(this).remove();
                         }
                     });
-                    $ajaxDialog.find('input[name^=params]').first().focus();
+                    $ajaxDialog.find('input[name^=params]').first().trigger('focus');
                     /**
                      * Attach the datepickers to the relevant form fields
                      */
                     $ajaxDialog.find('input.datefield, input.datetimefield').each(function () {
-                        PMA_addDatepicker($(this).css('width', '95%'));
+                        Functions.addDatepicker($(this).css('width', '95%'));
                     });
                     /*
                     * Define the function if the user presses enter
@@ -886,29 +885,29 @@ RTE.ROUTINE = {
                             * @var data Form data to be sent in the AJAX request
                             */
                             var data = $(this).serialize();
-                            $msg = PMA_ajaxShowMessage(
-                                PMA_messages.strProcessingRequest
+                            $msg = Functions.ajaxShowMessage(
+                                Messages.strProcessingRequest
                             );
                             var url = $(this).attr('action');
                             $.post(url, data, function (data) {
                                 if (data.success === true) {
                                     // Routine executed successfully
-                                    PMA_ajaxRemoveMessage($msg);
-                                    PMA_slidingMessage(data.message);
+                                    Functions.ajaxRemoveMessage($msg);
+                                    Functions.slidingMessage(data.message);
                                     $('form.rte_form').off('keyup');
                                     $ajaxDialog.remove();
                                 } else {
-                                    PMA_ajaxShowMessage(data.error, false);
+                                    Functions.ajaxShowMessage(data.error, false);
                                 }
                             });
                         }
                     });
                 } else {
                     // Routine executed successfully
-                    PMA_slidingMessage(data.message);
+                    Functions.slidingMessage(data.message);
                 }
             } else {
-                PMA_ajaxShowMessage(data.error, false);
+                Functions.ajaxShowMessage(data.error, false);
             }
         }); // end $.post()
     }
@@ -933,7 +932,7 @@ $(function () {
         } else {
             type = '';
         }
-        var dialog = new RTE.object(type);
+        var dialog = new RTE.Object(type);
         dialog.editorDialog($(this).hasClass('add_anchor'), $(this));
     }); // end $(document).on()
 
@@ -942,7 +941,7 @@ $(function () {
      */
     $(document).on('click', 'a.ajax.exec_anchor', function (event) {
         event.preventDefault();
-        var dialog = new RTE.object('routine');
+        var dialog = new RTE.Object('routine');
         dialog.executeDialog($(this));
     }); // end $(document).on()
 
@@ -951,13 +950,13 @@ $(function () {
      */
     $(document).on('click', 'a.ajax.export_anchor', function (event) {
         event.preventDefault();
-        var dialog = new RTE.object();
+        var dialog = new RTE.Object();
         dialog.exportDialog($(this));
     }); // end $(document).on()
 
     $(document).on('click', '#rteListForm.ajax .mult_submit[value="export"]', function (event) {
         event.preventDefault();
-        var dialog = new RTE.object();
+        var dialog = new RTE.Object();
         dialog.exportDialog($(this));
     }); // end $(document).on()
 
@@ -967,13 +966,13 @@ $(function () {
      */
     $(document).on('click', 'a.ajax.drop_anchor', function (event) {
         event.preventDefault();
-        var dialog = new RTE.object();
+        var dialog = new RTE.Object();
         dialog.dropDialog($(this));
     }); // end $(document).on()
 
     $(document).on('click', '#rteListForm.ajax .mult_submit[value="drop"]', function (event) {
         event.preventDefault();
-        var dialog = new RTE.object();
+        var dialog = new RTE.Object();
         dialog.dropMultipleDialog($(this));
     }); // end $(document).on()
 
@@ -1001,7 +1000,7 @@ $(function () {
          *          a row in the routine parameters table
          */
         var $row = $(this).parents('tr').first();
-        var rte = new RTE.object('routine');
+        var rte = new RTE.Object('routine');
         rte.setOptionsForParameter(
             $row.find('select[name^=item_param_type]'),
             $row.find('input[name^=item_param_length]'),
@@ -1016,7 +1015,7 @@ $(function () {
      * if any, are shown when changing the function return type type
      */
     $(document).on('change', 'select[name=item_returntype]', function () {
-        var rte = new RTE.object('routine');
+        var rte = new RTE.Object('routine');
         var $table = $(this).closest('table.rte_table');
         rte.setOptionsForParameter(
             $table.find('select[name=item_returntype]'),
@@ -1035,14 +1034,14 @@ $(function () {
          * @var routine_params_table jQuery object containing the reference
          *                           to the routine parameters table
          */
-        var $routine_params_table = $(this).closest('div.ui-dialog').find('.routine_params_table');
+        var $routineParamsTable = $(this).closest('div.ui-dialog').find('.routine_params_table');
         /**
          * @var new_param_row A string containing the HTML code for the
          *                    new row for the routine parameters table
          */
-        var new_param_row = RTE.param_template.replace(/%s/g, $routine_params_table.find('tr').length - 1);
+        var newParamRow = RTE.paramTemplate.replace(/%s/g, $routineParamsTable.find('tr').length - 1);
         // Append the new row to the parameters table
-        $routine_params_table.append(new_param_row);
+        $routineParamsTable.append(newParamRow);
         // Make sure that the row is correctly shown according to the type of routine
         if ($(this).closest('div.ui-dialog').find('table.rte_table select[name=item_type]').val() === 'FUNCTION') {
             $('tr.routine_return_row').show();
@@ -1054,7 +1053,7 @@ $(function () {
          */
         var $newrow = $(this).closest('div.ui-dialog').find('table.routine_params_table').find('tr').has('td').last();
         // Enable/disable the 'options' dropdowns for parameters as necessary
-        var rte = new RTE.object('routine');
+        var rte = new RTE.Object('routine');
         rte.setOptionsForParameter(
             $newrow.find('select[name^=item_param_type]'),
             $newrow.find('input[name^=item_param_length]'),
