@@ -5,8 +5,14 @@
  *
  * @package PhpMyAdmin
  */
+declare(strict_types=1);
+
 namespace PhpMyAdmin\Config\Forms\Page;
 
+/**
+ * Class NaviForm
+ * @package PhpMyAdmin\Config\Forms\Page
+ */
 class NaviForm extends \PhpMyAdmin\Config\Forms\User\NaviForm
 {
 }
