@@ -5,6 +5,8 @@
  *
  * @package PhpMyAdmin
  */
+declare(strict_types=1);
+
 namespace PhpMyAdmin\Config;
 
 use PhpMyAdmin\Config\ConfigFile;
@@ -53,11 +55,14 @@ class ServerConfigChecks
 
         list($cookieAuthUsed, $blowfishSecret, $blowfishSecretSet)
             = $this->performConfigChecksServers(
-                $cookieAuthUsed, $blowfishSecret, $blowfishSecretSet
+                $cookieAuthUsed,
+                $blowfishSecret,
+                $blowfishSecretSet
             );
 
         $this->performConfigChecksCookieAuthUsed(
-            $cookieAuthUsed, $blowfishSecretSet,
+            $cookieAuthUsed,
+            $blowfishSecretSet,
             $blowfishSecret
         );
 
@@ -75,18 +80,18 @@ class ServerConfigChecks
                     . 'reliable if your IP belongs to an ISP where thousands of users, '
                     . 'including you, are connected to.'
                 ),
-                '[a@' . Url::getCommon(array('page' => 'form', 'formset' => 'Features')) . '#tab_Security]',
+                '[a@' . Url::getCommon(['page' => 'form', 'formset' => 'Features']) . '#tab_Security]',
                 '[/a]',
-                '[a@' . Url::getCommon(array('page' => 'form', 'formset' => 'Features')) . '#tab_Security]',
+                '[a@' . Url::getCommon(['page' => 'form', 'formset' => 'Features']) . '#tab_Security]',
                 '[/a]',
-                '[a@' . Url::getCommon(array('page' => 'form', 'formset' => 'Features')) . '#tab_Security]',
+                '[a@' . Url::getCommon(['page' => 'form', 'formset' => 'Features']) . '#tab_Security]',
                 '[/a]'
             );
             SetupIndex::messagesSet(
                 'notice',
                 'AllowArbitraryServer',
                 Descriptions::get('AllowArbitraryServer'),
-                Sanitize::sanitize($sAllowArbitraryServerWarn)
+                Sanitize::sanitizeMessage($sAllowArbitraryServerWarn)
             );
         }
 
@@ -107,7 +112,7 @@ class ServerConfigChecks
                 'notice',
                 'SaveDir',
                 Descriptions::get('SaveDir'),
-                Sanitize::sanitize($sDirectoryNotice)
+                Sanitize::sanitizeMessage($sDirectoryNotice)
             );
         }
 
@@ -120,7 +125,7 @@ class ServerConfigChecks
                 'notice',
                 'TempDir',
                 Descriptions::get('TempDir'),
-                Sanitize::sanitize($sDirectoryNotice)
+                Sanitize::sanitizeMessage($sDirectoryNotice)
             );
         }
 
@@ -137,7 +142,8 @@ class ServerConfigChecks
      * @return array
      */
     protected function performConfigChecksServers(
-        $cookieAuthUsed, $blowfishSecret,
+        $cookieAuthUsed,
+        $blowfishSecret,
         $blowfishSecretSet
     ) {
         $serverCnt = $this->cfg->getServerCount();
@@ -146,20 +152,23 @@ class ServerConfigChecks
                 = ($this->cfg->getValue("Servers/$i/auth_type") == 'cookie');
             $cookieAuthUsed |= $cookieAuthServer;
             $serverName = $this->performConfigChecksServersGetServerName(
-                $this->cfg->getServerName($i), $i
+                $this->cfg->getServerName($i),
+                $i
             );
             $serverName = htmlspecialchars($serverName);
 
             list($blowfishSecret, $blowfishSecretSet)
                 = $this->performConfigChecksServersSetBlowfishSecret(
-                    $blowfishSecret, $cookieAuthServer, $blowfishSecretSet
+                    $blowfishSecret,
+                    $cookieAuthServer,
+                    $blowfishSecretSet
                 );
 
             //
             // $cfg['Servers'][$i]['ssl']
             // should be enabled if possible
             //
-            if (!$this->cfg->getValue("Servers/$i/ssl")) {
+            if (! $this->cfg->getValue("Servers/$i/ssl")) {
                 $title = Descriptions::get('Servers/1/ssl') . " ($serverName)";
                 SetupIndex::messagesSet(
                     'notice',
@@ -171,16 +180,16 @@ class ServerConfigChecks
                     )
                 );
             }
-            $sSecurityInfoMsg = Sanitize::sanitize(sprintf(
+            $sSecurityInfoMsg = Sanitize::sanitizeMessage(sprintf(
                 __(
                     'If you feel this is necessary, use additional protection settings - '
                     . '%1$shost authentication%2$s settings and %3$strusted proxies list%4%s. '
                     . 'However, IP-based protection may not be reliable if your IP belongs '
                     . 'to an ISP where thousands of users, including you, are connected to.'
                 ),
-                '[a@' . Url::getCommon(array('page' => 'servers', 'mode' => 'edit', 'id' => $i)) . '#tab_Server_config]',
+                '[a@' . Url::getCommon(['page' => 'servers', 'mode' => 'edit', 'id' => $i]) . '#tab_Server_config]',
                 '[/a]',
-                '[a@' . Url::getCommon(array('page' => 'form', 'formset' => 'Features')) . '#tab_Security]',
+                '[a@' . Url::getCommon(['page' => 'form', 'formset' => 'Features']) . '#tab_Security]',
                 '[/a]'
             ));
 
@@ -198,7 +207,7 @@ class ServerConfigChecks
                     'notice',
                     "Servers/$i/auth_type",
                     $title,
-                    Sanitize::sanitize(sprintf(
+                    Sanitize::sanitizeMessage(sprintf(
                         __(
                             'You set the [kbd]config[/kbd] authentication type and included '
                             . 'username and password for auto-login, which is not a desirable '
@@ -206,7 +215,7 @@ class ServerConfigChecks
                             . 'URL can directly access your phpMyAdmin panel. Set %1$sauthentication '
                             . 'type%2$s to [kbd]cookie[/kbd] or [kbd]http[/kbd].'
                         ),
-                        '[a@' . Url::getCommon(array('page' => 'servers', 'mode' => 'edit', 'id' => $i)) . '#tab_Server]',
+                        '[a@' . Url::getCommon(['page' => 'servers', 'mode' => 'edit', 'id' => $i]) . '#tab_Server]',
                         '[/a]'
                     ))
                     . ' ' . $sSecurityInfoMsg
@@ -232,7 +241,11 @@ class ServerConfigChecks
                 );
             }
         }
-        return array($cookieAuthUsed, $blowfishSecret, $blowfishSecretSet);
+        return [
+            $cookieAuthUsed,
+            $blowfishSecret,
+            $blowfishSecretSet,
+        ];
     }
 
     /**
@@ -245,13 +258,18 @@ class ServerConfigChecks
      * @return array
      */
     protected function performConfigChecksServersSetBlowfishSecret(
-        $blowfishSecret, $cookieAuthServer, $blowfishSecretSet
+        $blowfishSecret,
+        $cookieAuthServer,
+        $blowfishSecretSet
     ) {
         if ($cookieAuthServer && $blowfishSecret === null) {
             $blowfishSecretSet = true;
             $this->cfg->set('blowfish_secret', Util::generateRandom(32));
         }
-        return array($blowfishSecret, $blowfishSecretSet);
+        return [
+            $blowfishSecret,
+            $blowfishSecretSet,
+        ];
     }
 
     /**
@@ -263,7 +281,8 @@ class ServerConfigChecks
      * @return string Server name
      */
     protected function performConfigChecksServersGetServerName(
-        $serverName, $serverId
+        $serverName,
+        $serverId
     ) {
         if ($serverName == 'localhost') {
             $serverName .= " [$serverId]";
@@ -277,7 +296,8 @@ class ServerConfigChecks
      *
      * @return void
      */
-    protected function performConfigChecksZips() {
+    protected function performConfigChecksZips()
+    {
         $this->performConfigChecksServerGZipdump();
         $this->performConfigChecksServerBZipdump();
         $this->performConfigChecksServersZipdump();
@@ -288,22 +308,23 @@ class ServerConfigChecks
      *
      * @return void
      */
-    protected function performConfigChecksServersZipdump() {
+    protected function performConfigChecksServersZipdump()
+    {
         //
         // $cfg['ZipDump']
         // requires zip_open in import
         //
-        if ($this->cfg->getValue('ZipDump') && !$this->functionExists('zip_open')) {
+        if ($this->cfg->getValue('ZipDump') && ! $this->functionExists('zip_open')) {
             SetupIndex::messagesSet(
                 'error',
                 'ZipDump_import',
                 Descriptions::get('ZipDump'),
-                Sanitize::sanitize(sprintf(
+                Sanitize::sanitizeMessage(sprintf(
                     __(
                         '%sZip decompression%s requires functions (%s) which are unavailable '
                         . 'on this system.'
                     ),
-                    '[a@' . Url::getCommon(array('page' => 'form', 'formset' => 'Features')) . '#tab_Import_export]',
+                    '[a@' . Url::getCommon(['page' => 'form', 'formset' => 'Features']) . '#tab_Import_export]',
                     '[/a]',
                     'zip_open'
                 ))
@@ -314,17 +335,17 @@ class ServerConfigChecks
         // $cfg['ZipDump']
         // requires gzcompress in export
         //
-        if ($this->cfg->getValue('ZipDump') && !$this->functionExists('gzcompress')) {
+        if ($this->cfg->getValue('ZipDump') && ! $this->functionExists('gzcompress')) {
             SetupIndex::messagesSet(
                 'error',
                 'ZipDump_export',
                 Descriptions::get('ZipDump'),
-                Sanitize::sanitize(sprintf(
+                Sanitize::sanitizeMessage(sprintf(
                     __(
                         '%sZip compression%s requires functions (%s) which are unavailable on '
                         . 'this system.'
                     ),
-                    '[a@' . Url::getCommon(array('page' => 'form', 'formset' => 'Features')) . '#tab_Import_export]',
+                    '[a@' . Url::getCommon(['page' => 'form', 'formset' => 'Features']) . '#tab_Import_export]',
                     '[/a]',
                     'gzcompress'
                 ))
@@ -339,10 +360,11 @@ class ServerConfigChecks
      * @param boolean $blowfishSecretSet Blowfish secret set
      * @param string  $blowfishSecret    Blowfish secret
      *
-     * @return array
+     * @return void
      */
     protected function performConfigChecksCookieAuthUsed(
-        $cookieAuthUsed, $blowfishSecretSet,
+        $cookieAuthUsed,
+        $blowfishSecretSet,
         $blowfishSecret
     ) {
         //
@@ -356,7 +378,7 @@ class ServerConfigChecks
                     'notice',
                     'blowfish_secret_created',
                     Descriptions::get('blowfish_secret'),
-                    Sanitize::sanitize(__(
+                    Sanitize::sanitizeMessage(__(
                         'You didn\'t have blowfish secret set and have enabled '
                         . '[kbd]cookie[/kbd] authentication, so a key was automatically '
                         . 'generated for you. It is used to encrypt cookies; you don\'t need to '
@@ -364,7 +386,7 @@ class ServerConfigChecks
                     ))
                 );
             } else {
-                $blowfishWarnings = array();
+                $blowfishWarnings = [];
                 // check length
                 if (strlen($blowfishSecret) < 32) {
                     // too short key
@@ -373,23 +395,23 @@ class ServerConfigChecks
                     );
                 }
                 // check used characters
-                $hasDigits = (bool)preg_match('/\d/', $blowfishSecret);
-                $hasChars = (bool)preg_match('/\S/', $blowfishSecret);
-                $hasNonword = (bool)preg_match('/\W/', $blowfishSecret);
-                if (!$hasDigits || !$hasChars || !$hasNonword) {
-                    $blowfishWarnings[] = Sanitize::sanitize(
+                $hasDigits = (bool) preg_match('/\d/', $blowfishSecret);
+                $hasChars = (bool) preg_match('/\S/', $blowfishSecret);
+                $hasNonword = (bool) preg_match('/\W/', $blowfishSecret);
+                if (! $hasDigits || ! $hasChars || ! $hasNonword) {
+                    $blowfishWarnings[] = Sanitize::sanitizeMessage(
                         __(
                             'Key should contain letters, numbers [em]and[/em] '
                             . 'special characters.'
                         )
                     );
                 }
-                if (!empty($blowfishWarnings)) {
+                if (! empty($blowfishWarnings)) {
                     SetupIndex::messagesSet(
                         'error',
                         'blowfish_warnings' . count($blowfishWarnings),
                         Descriptions::get('blowfish_secret'),
-                        implode('<br />', $blowfishWarnings)
+                        implode('<br>', $blowfishWarnings)
                     );
                 }
             }
@@ -401,7 +423,8 @@ class ServerConfigChecks
      *
      * @return void
      */
-    protected function performConfigChecksLoginCookie() {
+    protected function performConfigChecksLoginCookie()
+    {
         //
         // $cfg['LoginCookieValidity']
         // value greater than session.gc_maxlifetime will cause
@@ -413,13 +436,13 @@ class ServerConfigChecks
                 'error',
                 'LoginCookieValidity',
                 Descriptions::get('LoginCookieValidity'),
-                Sanitize::sanitize(sprintf(
+                Sanitize::sanitizeMessage(sprintf(
                     __(
                         '%1$sLogin cookie validity%2$s greater than %3$ssession.gc_maxlifetime%4$s may '
                         . 'cause random session invalidation (currently session.gc_maxlifetime '
                         . 'is %5$d).'
                     ),
-                    '[a@' . Url::getCommon(array('page' => 'form', 'formset' => 'Features')) . '#tab_Security]',
+                    '[a@' . Url::getCommon(['page' => 'form', 'formset' => 'Features']) . '#tab_Security]',
                     '[/a]',
                     '[a@' . Core::getPHPDocLink('session.configuration.php#ini.session.gc-maxlifetime') . ']',
                     '[/a]',
@@ -437,13 +460,13 @@ class ServerConfigChecks
                 'notice',
                 'LoginCookieValidity',
                 Descriptions::get('LoginCookieValidity'),
-                Sanitize::sanitize(sprintf(
+                Sanitize::sanitizeMessage(sprintf(
                     __(
                         '%sLogin cookie validity%s should be set to 1800 seconds (30 minutes) '
                         . 'at most. Values larger than 1800 may pose a security risk such as '
                         . 'impersonation.'
                     ),
-                    '[a@' . Url::getCommon(array('page' => 'form', 'formset' => 'Features')) . '#tab_Security]',
+                    '[a@' . Url::getCommon(['page' => 'form', 'formset' => 'Features']) . '#tab_Security]',
                     '[/a]'
                 ))
             );
@@ -461,15 +484,15 @@ class ServerConfigChecks
                 'error',
                 'LoginCookieValidity',
                 Descriptions::get('LoginCookieValidity'),
-                Sanitize::sanitize(sprintf(
+                Sanitize::sanitizeMessage(sprintf(
                     __(
                         'If using [kbd]cookie[/kbd] authentication and %sLogin cookie store%s '
                         . 'is not 0, %sLogin cookie validity%s must be set to a value less or '
                         . 'equal to it.'
                     ),
-                    '[a@' . Url::getCommon(array('page' => 'form', 'formset' => 'Features')) . '#tab_Security]',
+                    '[a@' . Url::getCommon(['page' => 'form', 'formset' => 'Features']) . '#tab_Security]',
                     '[/a]',
-                    '[a@' . Url::getCommon(array('page' => 'form', 'formset' => 'Features')) . '#tab_Security]',
+                    '[a@' . Url::getCommon(['page' => 'form', 'formset' => 'Features']) . '#tab_Security]',
                     '[/a]'
                 ))
             );
@@ -488,7 +511,7 @@ class ServerConfigChecks
         // requires bzip2 functions
         //
         if ($this->cfg->getValue('BZipDump')
-            && (!$this->functionExists('bzopen') || !$this->functionExists('bzcompress'))
+            && (! $this->functionExists('bzopen') || ! $this->functionExists('bzcompress'))
         ) {
             $functions = $this->functionExists('bzopen')
                 ? '' :
@@ -500,13 +523,13 @@ class ServerConfigChecks
                 'error',
                 'BZipDump',
                 Descriptions::get('BZipDump'),
-                Sanitize::sanitize(
+                Sanitize::sanitizeMessage(
                     sprintf(
-                         __(
+                        __(
                             '%1$sBzip2 compression and decompression%2$s requires functions (%3$s) which '
-                            . 'are unavailable on this system.'
+                             . 'are unavailable on this system.'
                         ),
-                        '[a@' . Url::getCommon(array('page' => 'form', 'formset' => 'Features')) . '#tab_Import_export]',
+                        '[a@' . Url::getCommon(['page' => 'form', 'formset' => 'Features']) . '#tab_Import_export]',
                         '[/a]',
                         $functions
                     )
@@ -527,18 +550,18 @@ class ServerConfigChecks
         // requires zlib functions
         //
         if ($this->cfg->getValue('GZipDump')
-            && (!$this->functionExists('gzopen') || !$this->functionExists('gzencode'))
+            && (! $this->functionExists('gzopen') || ! $this->functionExists('gzencode'))
         ) {
             SetupIndex::messagesSet(
                 'error',
                 'GZipDump',
                 Descriptions::get('GZipDump'),
-                Sanitize::sanitize(sprintf(
+                Sanitize::sanitizeMessage(sprintf(
                     __(
                         '%1$sGZip compression and decompression%2$s requires functions (%3$s) which '
                         . 'are unavailable on this system.'
                     ),
-                    '[a@' . Url::getCommon(array('page' => 'form', 'formset' => 'Features')) . '#tab_Import_export]',
+                    '[a@' . Url::getCommon(['page' => 'form', 'formset' => 'Features']) . '#tab_Import_export]',
                     '[/a]',
                     'gzencode'
                 ))
