@@ -5,6 +5,8 @@
  *
  * @package PhpMyAdmin-Designer
  */
+declare(strict_types=1);
+
 namespace PhpMyAdmin\Database\Designer;
 
 use PhpMyAdmin\DatabaseInterface;
@@ -12,6 +14,7 @@ use PhpMyAdmin\Index;
 use PhpMyAdmin\Relation;
 use PhpMyAdmin\Table;
 use PhpMyAdmin\Util;
+use function rawurlencode;
 use PhpMyAdmin\Database\Designer\DesignerTable;
 
 /**
@@ -22,16 +25,25 @@ use PhpMyAdmin\Database\Designer\DesignerTable;
 class Common
 {
     /**
-     * @var Relation $relation
+     * @var Relation
      */
     private $relation;
 
     /**
-     * Constructor
+     * @var DatabaseInterface
      */
-    public function __construct()
+    private $dbi;
+
+    /**
+     * Common constructor.
+     *
+     * @param DatabaseInterface $dbi      DatabaseInterface object
+     * @param Relation          $relation Relation instance
+     */
+    public function __construct(DatabaseInterface $dbi, Relation $relation)
     {
-        $this->relation = new Relation();
+        $this->dbi = $dbi;
+        $this->relation = $relation;
     }
 
     /**
@@ -41,16 +53,16 @@ class Common
      * @param string $table (optional) Filter only a table ($db is now required)
      * @return DesignerTable[] with table info
      */
-    public function getTablesInfo($db = null, $table = null)
+    public function getTablesInfo(string $db = null, string $table = null): array
     {
-        $designerTables = array();
+        $designerTables = [];
         $db = ($db === null) ? $GLOBALS['db'] : $db;
         // seems to be needed later
-        $GLOBALS['dbi']->selectDb($db);
+        $this->dbi->selectDb($db);
         if ($db === null && $table === null) {
-            $tables = $GLOBALS['dbi']->getTablesFull($db);
+            $tables = $this->dbi->getTablesFull($db);
         } else {
-            $tables = $GLOBALS['dbi']->getTablesFull($db, $table);
+            $tables = $this->dbi->getTablesFull($db, $table);
         }
 
         foreach ($tables as $one_table) {
@@ -58,11 +70,11 @@ class Common
             $DF = is_string($DF) ? $DF : '';
             $DF = ($DF !== '') ? $DF : null;
             $designerTables[] = new DesignerTable(
-                                    $db,
-                                    $one_table['TABLE_NAME'],
-                                    $one_table['ENGINE'],
-                                    $DF
-                                );
+                $db,
+                $one_table['TABLE_NAME'],
+                is_string($one_table['ENGINE']) ? $one_table['ENGINE'] : '',
+                $DF
+            );
         }
 
         return $designerTables;
@@ -74,14 +86,14 @@ class Common
      * @param DesignerTable[] $designerTables The designer tables
      * @return array table column nfo
      */
-    public function getColumnsInfo($designerTables)
+    public function getColumnsInfo(array $designerTables): array
     {
-        //$GLOBALS['dbi']->selectDb($GLOBALS['db']);
-        $tabColumn = array();
+        //$this->dbi->selectDb($GLOBALS['db']);
+        $tabColumn = [];
 
-        foreach($designerTables as $designerTable) {
-            $fieldsRs = $GLOBALS['dbi']->query(
-                $GLOBALS['dbi']->getColumnsSql(
+        foreach ($designerTables as $designerTable) {
+            $fieldsRs = $this->dbi->query(
+                $this->dbi->getColumnsSql(
                     $designerTable->getDatabaseName(),
                     $designerTable->getTableName(),
                     null,
@@ -91,7 +103,7 @@ class Common
                 DatabaseInterface::QUERY_STORE
             );
             $j = 0;
-            while ($row = $GLOBALS['dbi']->fetchAssoc($fieldsRs)) {
+            while ($row = $this->dbi->fetchAssoc($fieldsRs)) {
                 if (! isset($tabColumn[$designerTable->getDbTableString()])) {
                     $tabColumn[$designerTable->getDbTableString()] = [];
                 }
@@ -110,20 +122,20 @@ class Common
      * Returns JavaScript code for initializing vars
      *
      * @param DesignerTable[] $designerTables The designer tables
-     * @return string   JavaScript code
+     * @return array JavaScript code
      */
-    public function getScriptContr($designerTables)
+    public function getScriptContr(array $designerTables): array
     {
-        $GLOBALS['dbi']->selectDb($GLOBALS['db']);
-        $con = array();
-        $con["C_NAME"] = array();
+        $this->dbi->selectDb($GLOBALS['db']);
+        $con = [];
+        $con["C_NAME"] = [];
         $i = 0;
-        $alltab_rs = $GLOBALS['dbi']->query(
+        $alltab_rs = $this->dbi->query(
             'SHOW TABLES FROM ' . Util::backquote($GLOBALS['db']),
             DatabaseInterface::CONNECT_USER,
             DatabaseInterface::QUERY_STORE
         );
-        while ($val = @$GLOBALS['dbi']->fetchRow($alltab_rs)) {
+        while ($val = @$this->dbi->fetchRow($alltab_rs)) {
             $row = $this->relation->getForeigners($GLOBALS['db'], $val[0], '', 'internal');
 
             if ($row !== false) {
@@ -160,23 +172,23 @@ class Common
         }
 
         $tableDbNames = [];
-        foreach($designerTables as $designerTable) {
+        foreach ($designerTables as $designerTable) {
             $tableDbNames[] = $designerTable->getDbTableString();
         }
 
         $ti = 0;
-        $retval = array();
+        $retval = [];
         for ($i = 0, $cnt = count($con["C_NAME"]); $i < $cnt; $i++) {
             $c_name_i = $con['C_NAME'][$i];
             $dtn_i = $con['DTN'][$i];
-            $retval[$ti] = array();
-            $retval[$ti][$c_name_i] = array();
+            $retval[$ti] = [];
+            $retval[$ti][$c_name_i] = [];
             if (in_array($dtn_i, $tableDbNames) && in_array($con['STN'][$i], $tableDbNames)) {
-                $retval[$ti][$c_name_i][$dtn_i] = array();
-                $retval[$ti][$c_name_i][$dtn_i][$con['DCN'][$i]] = array(
+                $retval[$ti][$c_name_i][$dtn_i] = [];
+                $retval[$ti][$c_name_i][$dtn_i][$con['DCN'][$i]] = [
                     0 => $con['STN'][$i],
-                    1 => $con['SCN'][$i]
-                );
+                    1 => $con['SCN'][$i],
+                ];
             }
             $ti++;
         }
@@ -189,7 +201,7 @@ class Common
      * @param DesignerTable[] $designerTables The designer tables
      * @return array unique or primary indices
      */
-    public function getPkOrUniqueKeys($designerTables)
+    public function getPkOrUniqueKeys(array $designerTables): array
     {
         return $this->getAllKeys($designerTables, true);
     }
@@ -202,9 +214,9 @@ class Common
      *
      * @return array indices
      */
-    public function getAllKeys($designerTables, $unique_only = false)
+    public function getAllKeys(array $designerTables, bool $unique_only = false): array
     {
-        $keys = array();
+        $keys = [];
 
         foreach ($designerTables as $designerTable) {
             $schema = $designerTable->getDatabaseName();
@@ -228,14 +240,14 @@ class Common
      * @param DesignerTable[] $designerTables The designer tables
      * @return array
      */
-    public function getScriptTabs($designerTables)
+    public function getScriptTabs(array $designerTables): array
     {
-        $retval = array(
-            'j_tabs' => array(),
-            'h_tabs' => array()
-        );
+        $retval = [
+            'j_tabs' => [],
+            'h_tabs' => [],
+        ];
 
-        foreach($designerTables as $designerTable) {
+        foreach ($designerTables as $designerTable) {
             $key = rawurlencode($designerTable->getDbTableString());
             $retval['j_tabs'][$key] = $designerTable->supportsForeignkeys() ? 1 : 0;
             $retval['h_tabs'][$key] = 1;
@@ -249,13 +261,13 @@ class Common
      *
      * @param int $pg pdf page id
      *
-     * @return array of table positions
+     * @return array|null of table positions
      */
-    public function getTablePositions($pg)
+    public function getTablePositions($pg): ?array
     {
         $cfgRelation = $this->relation->getRelationsParam();
         if (! $cfgRelation['pdfwork']) {
-            return array();
+            return [];
         }
 
         $query = "
@@ -269,14 +281,13 @@ class Common
                 . "." . Util::backquote($cfgRelation['table_coords']) . "
             WHERE pdf_page_number = " . intval($pg);
 
-        $tab_pos = $GLOBALS['dbi']->fetchResult(
+        return $this->dbi->fetchResult(
             $query,
             'name',
             null,
             DatabaseInterface::CONNECT_CONTROL,
             DatabaseInterface::QUERY_STORE
         );
-        return $tab_pos;
     }
 
     /**
@@ -297,7 +308,7 @@ class Common
             . " FROM " . Util::backquote($cfgRelation['db'])
             . "." . Util::backquote($cfgRelation['pdf_pages'])
             . " WHERE " . Util::backquote('page_nr') . " = " . intval($pg);
-        $page_name = $GLOBALS['dbi']->fetchResult(
+        $page_name = $this->dbi->fetchResult(
             $query,
             null,
             null,
@@ -325,7 +336,9 @@ class Common
             . "." . Util::backquote($cfgRelation['table_coords'])
             . " WHERE " . Util::backquote('pdf_page_number') . " = " . intval($pg);
         $success = $this->relation->queryAsControlUser(
-            $query, true, DatabaseInterface::QUERY_STORE
+            $query,
+            true,
+            DatabaseInterface::QUERY_STORE
         );
 
         if ($success) {
@@ -333,11 +346,13 @@ class Common
                 . "." . Util::backquote($cfgRelation['pdf_pages'])
                 . " WHERE " . Util::backquote('page_nr') . " = " . intval($pg);
             $success = $this->relation->queryAsControlUser(
-                $query, true, DatabaseInterface::QUERY_STORE
+                $query,
+                true,
+                DatabaseInterface::QUERY_STORE
             );
         }
 
-        return (boolean) $success;
+        return (bool) $success;
     }
 
     /**
@@ -346,9 +361,9 @@ class Common
      *
      * @param string $db database
      *
-     * @return int id of the default pdf page for the database
+     * @return int|null id of the default pdf page for the database
      */
-    public function getDefaultPage($db)
+    public function getDefaultPage($db): ?int
     {
         $cfgRelation = $this->relation->getRelationsParam();
         if (! $cfgRelation['pdfwork']) {
@@ -358,10 +373,10 @@ class Common
         $query = "SELECT `page_nr`"
             . " FROM " . Util::backquote($cfgRelation['db'])
             . "." . Util::backquote($cfgRelation['pdf_pages'])
-            . " WHERE `db_name` = '" . $GLOBALS['dbi']->escapeString($db) . "'"
-            . " AND `page_descr` = '" .  $GLOBALS['dbi']->escapeString($db) . "'";
+            . " WHERE `db_name` = '" . $this->dbi->escapeString($db) . "'"
+            . " AND `page_descr` = '" . $this->dbi->escapeString($db) . "'";
 
-        $default_page_no = $GLOBALS['dbi']->fetchResult(
+        $default_page_no = $this->dbi->fetchResult(
             $query,
             null,
             null,
@@ -399,9 +414,9 @@ class Common
             $query = "SELECT MIN(`page_nr`)"
                 . " FROM " . Util::backquote($cfgRelation['db'])
                 . "." . Util::backquote($cfgRelation['pdf_pages'])
-                . " WHERE `db_name` = '" . $GLOBALS['dbi']->escapeString($db) . "'";
+                . " WHERE `db_name` = '" . $this->dbi->escapeString($db) . "'";
 
-            $min_page_no = $GLOBALS['dbi']->fetchResult(
+            $min_page_no = $this->dbi->fetchResult(
                 $query,
                 null,
                 null,
@@ -427,12 +442,11 @@ class Common
     {
         $cfgRelation = $this->relation->getRelationsParam();
         if ($cfgRelation['pdfwork']) {
-            $pageNumber = $this->relation->createPage(
+            return $this->relation->createPage(
                 $pageName,
                 $cfgRelation,
                 $db
             );
-            return $pageNumber;
         }
         return null;
     }
@@ -446,9 +460,9 @@ class Common
      */
     public function saveTablePositions($pg)
     {
-        $pageId = $GLOBALS['dbi']->escapeString($pg);
+        $pageId = $this->dbi->escapeString($pg);
 
-        $db = $GLOBALS['dbi']->escapeString($_POST['db']);
+        $db = $this->dbi->escapeString($_POST['db']);
 
         $cfgRelation = $this->relation->getRelationsParam();
         if (! $cfgRelation['pdfwork']) {
@@ -468,14 +482,14 @@ class Common
             DatabaseInterface::QUERY_STORE
         );
 
-        if (!$res) {
-            return (boolean)$res;
+        if (! $res) {
+            return (bool) $res;
         }
 
         foreach ($_POST['t_h'] as $key => $value) {
             $DB = $_POST['t_db'][$key];
             $TAB = $_POST['t_tbl'][$key];
-            if (!$value) {
+            if (! $value) {
                 continue;
             }
 
@@ -484,18 +498,20 @@ class Common
                 . Util::backquote($cfgRelation['table_coords'])
                 . " (`db_name`, `table_name`, `pdf_page_number`, `x`, `y`)"
                 . " VALUES ("
-                . "'" . $GLOBALS['dbi']->escapeString($DB) . "', "
-                . "'" . $GLOBALS['dbi']->escapeString($TAB) . "', "
+                . "'" . $this->dbi->escapeString($DB) . "', "
+                . "'" . $this->dbi->escapeString($TAB) . "', "
                 . "'" . $pageId . "', "
-                . "'" . $GLOBALS['dbi']->escapeString($_POST['t_x'][$key]) . "', "
-                . "'" . $GLOBALS['dbi']->escapeString($_POST['t_y'][$key]) . "')";
+                . "'" . $this->dbi->escapeString($_POST['t_x'][$key]) . "', "
+                . "'" . $this->dbi->escapeString($_POST['t_y'][$key]) . "')";
 
             $res = $this->relation->queryAsControlUser(
-                $query,  true, DatabaseInterface::QUERY_STORE
+                $query,
+                true,
+                DatabaseInterface::QUERY_STORE
             );
         }
 
-        return (boolean) $res;
+        return (bool) $res;
     }
 
     /**
@@ -520,7 +536,7 @@ class Common
             ];
         }
 
-        $upd_query = new Table($table, $db, $GLOBALS['dbi']);
+        $upd_query = new Table($table, $db, $this->dbi);
         $upd_query->updateDisplayField($field, $cfgRelation);
 
         return [
@@ -546,9 +562,9 @@ class Common
      */
     public function addNewRelation($db, $T1, $F1, $T2, $F2, $on_delete, $on_update, $DB1, $DB2)
     {
-        $tables = $GLOBALS['dbi']->getTablesFull($DB1, $T1);
+        $tables = $this->dbi->getTablesFull($DB1, $T1);
         $type_T1 = mb_strtoupper($tables[$T1]['ENGINE']);
-        $tables = $GLOBALS['dbi']->getTablesFull($DB2, $T2);
+        $tables = $this->dbi->getTablesFull($DB2, $T2);
         $type_T2 = mb_strtoupper($tables[$T2]['ENGINE']);
 
         // native foreign key
@@ -562,33 +578,36 @@ class Common
             if ($foreigner
                 && isset($foreigner['constraint'])
             ) {
-                return array(false, __('Error: relationship already exists.'));
+                return [
+                    false,
+                    __('Error: relationship already exists.'),
+                ];
             }
             // note: in InnoDB, the index does not requires to be on a PRIMARY
             // or UNIQUE key
             // improve: check all other requirements for InnoDB relations
-            $result = $GLOBALS['dbi']->query(
+            $result = $this->dbi->query(
                 'SHOW INDEX FROM ' . Util::backquote($DB1)
                 . '.' . Util::backquote($T1) . ';'
             );
 
             // will be use to emphasis prim. keys in the table view
-            $index_array1 = array();
-            while ($row = $GLOBALS['dbi']->fetchAssoc($result)) {
+            $index_array1 = [];
+            while ($row = $this->dbi->fetchAssoc($result)) {
                 $index_array1[$row['Column_name']] = 1;
             }
-            $GLOBALS['dbi']->freeResult($result);
+            $this->dbi->freeResult($result);
 
-            $result = $GLOBALS['dbi']->query(
+            $result = $this->dbi->query(
                 'SHOW INDEX FROM ' . Util::backquote($DB2)
                 . '.' . Util::backquote($T2) . ';'
             );
             // will be used to emphasis prim. keys in the table view
-            $index_array2 = array();
-            while ($row = $GLOBALS['dbi']->fetchAssoc($result)) {
+            $index_array2 = [];
+            while ($row = $this->dbi->fetchAssoc($result)) {
                 $index_array2[$row['Column_name']] = 1;
             }
-            $GLOBALS['dbi']->freeResult($result);
+            $this->dbi->freeResult($result);
 
             if (! empty($index_array1[$F1]) && ! empty($index_array2[$F2])) {
                 $upd_query  = 'ALTER TABLE ' . Util::backquote($DB2)
@@ -607,24 +626,33 @@ class Common
                     $upd_query   .= ' ON UPDATE ' . $on_update;
                 }
                 $upd_query .= ';';
-                if ($GLOBALS['dbi']->tryQuery($upd_query)) {
-                    return array(true, __('FOREIGN KEY relationship has been added.'));
+                if ($this->dbi->tryQuery($upd_query)) {
+                    return [
+                        true,
+                        __('FOREIGN KEY relationship has been added.'),
+                    ];
                 }
 
-                $error = $GLOBALS['dbi']->getError();
-                return array(
+                $error = $this->dbi->getError();
+                return [
                     false,
                     __('Error: FOREIGN KEY relationship could not be added!')
-                    . "<br/>" . $error
-                );
+                    . "<br>" . $error,
+                ];
             }
 
-            return array(false, __('Error: Missing index on column(s).'));
+            return [
+                false,
+                __('Error: Missing index on column(s).'),
+            ];
         }
 
         // internal (pmadb) relation
         if ($GLOBALS['cfgRelation']['relwork'] == false) {
-            return array(false, __('Error: Relational features are disabled!'));
+            return [
+                false,
+                __('Error: Relational features are disabled!'),
+            ];
         }
 
         // no need to recheck if the keys are primary or unique at this point,
@@ -637,24 +665,27 @@ class Common
             . "(master_db, master_table, master_field, "
             . "foreign_db, foreign_table, foreign_field)"
             . " values("
-            . "'" . $GLOBALS['dbi']->escapeString($DB2) . "', "
-            . "'" . $GLOBALS['dbi']->escapeString($T2) . "', "
-            . "'" . $GLOBALS['dbi']->escapeString($F2) . "', "
-            . "'" . $GLOBALS['dbi']->escapeString($DB1) . "', "
-            . "'" . $GLOBALS['dbi']->escapeString($T1) . "', "
-            . "'" . $GLOBALS['dbi']->escapeString($F1) . "')";
+            . "'" . $this->dbi->escapeString($DB2) . "', "
+            . "'" . $this->dbi->escapeString($T2) . "', "
+            . "'" . $this->dbi->escapeString($F2) . "', "
+            . "'" . $this->dbi->escapeString($DB1) . "', "
+            . "'" . $this->dbi->escapeString($T1) . "', "
+            . "'" . $this->dbi->escapeString($F1) . "')";
 
         if ($this->relation->queryAsControlUser($q, false, DatabaseInterface::QUERY_STORE)
         ) {
-            return array(true, __('Internal relationship has been added.'));
+            return [
+                true,
+                __('Internal relationship has been added.'),
+            ];
         }
 
-        $error = $GLOBALS['dbi']->getError(DatabaseInterface::CONNECT_CONTROL);
-        return array(
+        $error = $this->dbi->getError(DatabaseInterface::CONNECT_CONTROL);
+        return [
             false,
             __('Error: Internal relationship could not be added!')
-            . "<br/>" . $error
-        );
+            . "<br>" . $error,
+        ];
     }
 
     /**
@@ -672,9 +703,9 @@ class Common
         list($DB1, $T1) = explode(".", $T1);
         list($DB2, $T2) = explode(".", $T2);
 
-        $tables = $GLOBALS['dbi']->getTablesFull($DB1, $T1);
+        $tables = $this->dbi->getTablesFull($DB1, $T1);
         $type_T1 = mb_strtoupper($tables[$T1]['ENGINE']);
-        $tables = $GLOBALS['dbi']->getTablesFull($DB2, $T2);
+        $tables = $this->dbi->getTablesFull($DB2, $T2);
         $type_T2 = mb_strtoupper($tables[$T2]['ENGINE']);
 
         if (Util::isForeignKeySupported($type_T1)
@@ -689,16 +720,19 @@ class Common
                 $upd_query = 'ALTER TABLE ' . Util::backquote($DB2)
                     . '.' . Util::backquote($T2) . ' DROP FOREIGN KEY '
                     . Util::backquote($foreigner['constraint']) . ';';
-                if ($GLOBALS['dbi']->query($upd_query)) {
-                    return array(true, __('FOREIGN KEY relationship has been removed.'));
+                if ($this->dbi->query($upd_query)) {
+                    return [
+                        true,
+                        __('FOREIGN KEY relationship has been removed.'),
+                    ];
                 }
 
-                $error = $GLOBALS['dbi']->getError();
-                return array(
+                $error = $this->dbi->getError();
+                return [
                     false,
                     __('Error: FOREIGN KEY relationship could not be removed!')
-                    . "<br/>" . $error
-                );
+                    . "<br>" . $error,
+                ];
             }
         }
 
@@ -706,12 +740,12 @@ class Common
         $delete_query = "DELETE FROM "
             . Util::backquote($GLOBALS['cfgRelation']['db']) . "."
             . $GLOBALS['cfgRelation']['relation'] . " WHERE "
-            . "master_db = '" . $GLOBALS['dbi']->escapeString($DB2) . "'"
-            . " AND master_table = '" . $GLOBALS['dbi']->escapeString($T2) . "'"
-            . " AND master_field = '" . $GLOBALS['dbi']->escapeString($F2) . "'"
-            . " AND foreign_db = '" . $GLOBALS['dbi']->escapeString($DB1) . "'"
-            . " AND foreign_table = '" . $GLOBALS['dbi']->escapeString($T1) . "'"
-            . " AND foreign_field = '" . $GLOBALS['dbi']->escapeString($F1) . "'";
+            . "master_db = '" . $this->dbi->escapeString($DB2) . "'"
+            . " AND master_table = '" . $this->dbi->escapeString($T2) . "'"
+            . " AND master_field = '" . $this->dbi->escapeString($F2) . "'"
+            . " AND foreign_db = '" . $this->dbi->escapeString($DB1) . "'"
+            . " AND foreign_table = '" . $this->dbi->escapeString($T1) . "'"
+            . " AND foreign_field = '" . $this->dbi->escapeString($F1) . "'";
 
         $result = $this->relation->queryAsControlUser(
             $delete_query,
@@ -719,15 +753,18 @@ class Common
             DatabaseInterface::QUERY_STORE
         );
 
-        if (!$result) {
-            $error = $GLOBALS['dbi']->getError(DatabaseInterface::CONNECT_CONTROL);
-            return array(
+        if (! $result) {
+            $error = $this->dbi->getError(DatabaseInterface::CONNECT_CONTROL);
+            return [
                 false,
-                __('Error: Internal relationship could not be removed!') . "<br/>" . $error
-            );
+                __('Error: Internal relationship could not be removed!') . "<br>" . $error,
+            ];
         }
 
-        return array(true, __('Internal relationship has been removed.'));
+        return [
+            true,
+            __('Internal relationship has been removed.'),
+        ];
     }
 
     /**
@@ -743,21 +780,22 @@ class Common
         $cfgRelation = $this->relation->getRelationsParam();
         $success = true;
         if ($cfgRelation['designersettingswork']) {
-
-            $cfgDesigner = array(
+            $cfgDesigner = [
                 'user'  => $GLOBALS['cfg']['Server']['user'],
                 'db'    => $cfgRelation['db'],
-                'table' => $cfgRelation['designer_settings']
-            );
+                'table' => $cfgRelation['designer_settings'],
+            ];
 
             $orig_data_query = "SELECT settings_data"
                 . " FROM " . Util::backquote($cfgDesigner['db'])
                 . "." . Util::backquote($cfgDesigner['table'])
                 . " WHERE username = '"
-                . $GLOBALS['dbi']->escapeString($cfgDesigner['user']) . "';";
+                . $this->dbi->escapeString($cfgDesigner['user']) . "';";
 
-            $orig_data = $GLOBALS['dbi']->fetchSingleRow(
-                $orig_data_query, 'ASSOC', DatabaseInterface::CONNECT_CONTROL
+            $orig_data = $this->dbi->fetchSingleRow(
+                $orig_data_query,
+                'ASSOC',
+                DatabaseInterface::CONNECT_CONTROL
             );
 
             if (! empty($orig_data)) {
@@ -770,17 +808,17 @@ class Common
                     . "." . Util::backquote($cfgDesigner['table'])
                     . " SET settings_data = '" . $orig_data . "'"
                     . " WHERE username = '"
-                    . $GLOBALS['dbi']->escapeString($cfgDesigner['user']) . "';";
+                    . $this->dbi->escapeString($cfgDesigner['user']) . "';";
 
                 $success = $this->relation->queryAsControlUser($save_query);
             } else {
-                $save_data = array($index => $value);
+                $save_data = [$index => $value];
 
                 $query = "INSERT INTO "
                     . Util::backquote($cfgDesigner['db'])
                     . "." . Util::backquote($cfgDesigner['table'])
                     . " (username, settings_data)"
-                    . " VALUES('" . $GLOBALS['dbi']->escapeString($cfgDesigner['user'])
+                    . " VALUES('" . $this->dbi->escapeString($cfgDesigner['user'])
                     . "', '" . json_encode($save_data) . "');";
 
                 $success = $this->relation->queryAsControlUser($query);
