@@ -5,6 +5,8 @@
  *
  * @package PhpMyAdmin-Navigation
  */
+declare(strict_types=1);
+
 namespace PhpMyAdmin\Navigation\Nodes;
 
 use PhpMyAdmin\Navigation\NodeFactory;
@@ -24,13 +26,13 @@ class NodeTriggerContainer extends Node
     {
         parent::__construct(__('Triggers'), Node::CONTAINER);
         $this->icon = Util::getImage('b_triggers');
-        $this->links = array(
+        $this->links = [
             'text' => 'db_triggers.php?server=' . $GLOBALS['server']
                 . '&amp;db=%2$s&amp;table=%1$s',
             'icon' => 'db_triggers.php?server=' . $GLOBALS['server']
                 . '&amp;db=%2$s&amp;table=%1$s',
-        );
-        $this->real_name = 'triggers';
+        ];
+        $this->realName = 'triggers';
 
         $new = NodeFactory::getInstance(
             'Node',
@@ -38,12 +40,12 @@ class NodeTriggerContainer extends Node
         );
         $new->isNew = true;
         $new->icon = Util::getImage('b_trigger_add', '');
-        $new->links = array(
+        $new->links = [
             'text' => 'db_triggers.php?server=' . $GLOBALS['server']
                 . '&amp;db=%3$s&amp;add_item=1',
             'icon' => 'db_triggers.php?server=' . $GLOBALS['server']
                 . '&amp;db=%3$s&amp;add_item=1',
-        );
+        ];
         $new->classes = 'new_trigger italics';
         $this->addChild($new);
     }
