@@ -5,6 +5,8 @@
  *
  * @package PhpMyAdmin
  */
+declare(strict_types=1);
+
 namespace PhpMyAdmin;
 
 use PhpMyAdmin\DatabaseInterface;
@@ -34,12 +36,12 @@ class Tracker
     /**
      * Whether tracking is ready.
      */
-    static protected $enabled = false;
+    protected static $enabled = false;
 
     /**
      * Cache to avoid quering tracking status multiple times.
      */
-    static protected $_tracking_cache = array();
+    protected static $_tracking_cache = [];
 
     /**
      * Actually enables tracking. This needs to be done after all
@@ -70,7 +72,7 @@ class Tracker
          * from Relation::getRelationsParam
          */
         self::$enabled = false;
-        $relation = new Relation();
+        $relation = new Relation($GLOBALS['dbi']);
         $cfgRelation = $relation->getRelationsParam();
         /* Restore original state */
         self::$enabled = true;
@@ -80,7 +82,7 @@ class Tracker
 
         $pma_table = self::_getTrackingTable();
 
-        return isset($pma_table);
+        return $pma_table !== null;
     }
 
     /**
@@ -92,7 +94,7 @@ class Tracker
      *
      * @return string the name of table
      */
-    static protected function getTableName($string)
+    protected static function getTableName($string)
     {
         if (mb_strstr($string, '.')) {
             $temp = explode('.', $string);
@@ -104,8 +106,7 @@ class Tracker
         $str = explode("\n", $tablename);
         $tablename = $str[0];
 
-        $tablename = str_replace(';', '', $tablename);
-        $tablename = str_replace('`', '', $tablename);
+        $tablename = str_replace([';', '`'], '', $tablename);
         $tablename = trim($tablename);
 
         return $tablename;
@@ -135,7 +136,7 @@ class Tracker
          * from Relation::getRelationsParam
          */
         self::$enabled = false;
-        $relation = new Relation();
+        $relation = new Relation($GLOBALS['dbi']);
         $cfgRelation = $relation->getRelationsParam();
         /* Restore original state */
         self::$enabled = true;
@@ -182,28 +183,34 @@ class Tracker
      *
      * @return int result of version insertion
      */
-    public static function createVersion($dbname, $tablename, $version,
-        $tracking_set = '', $is_view = false
+    public static function createVersion(
+        $dbname,
+        $tablename,
+        $version,
+        $tracking_set = '',
+        bool $is_view = false
     ) {
         global $sql_backquotes, $export_type;
 
-        $relation = new Relation();
+        $relation = new Relation($GLOBALS['dbi']);
 
         if ($tracking_set == '') {
             $tracking_set
                 = $GLOBALS['cfg']['Server']['tracking_default_statements'];
         }
 
-        // get Export SQL instance
-        /* @var $export_sql_plugin PhpMyAdmin\Plugins\Export\ExportSql */
+        /**
+         * get Export SQL instance
+         * @var ExportSql $export_sql_plugin
+         */
         $export_sql_plugin = Plugins::getPlugin(
             "export",
             "sql",
             'libraries/classes/Plugins/Export/',
-            array(
+            [
                 'export_type' => $export_type,
                 'single_table' => false,
-            )
+            ]
         );
 
         $sql_backquotes = true;
@@ -222,7 +229,10 @@ class Tracker
 
         $indexes = $GLOBALS['dbi']->getTableIndexes($dbname, $tablename);
 
-        $snapshot = array('COLUMNS' => $columns, 'INDEXES' => $indexes);
+        $snapshot = [
+            'COLUMNS' => $columns,
+            'INDEXES' => $indexes,
+        ];
         $snapshot = serialize($snapshot);
 
         // Get DROP TABLE / DROP VIEW and CREATE TABLE SQL statements
@@ -231,15 +241,14 @@ class Tracker
         $create_sql  = "";
 
         if ($GLOBALS['cfg']['Server']['tracking_add_drop_table'] == true
-            && $is_view == false
+            && $is_view === false
         ) {
             $create_sql .= self::getLogComment()
                 . 'DROP TABLE IF EXISTS ' . Util::backquote($tablename) . ";\n";
-
         }
 
         if ($GLOBALS['cfg']['Server']['tracking_add_drop_view'] == true
-            && $is_view == true
+            && $is_view === true
         ) {
             $create_sql .= self::getLogComment()
                 . 'DROP VIEW IF EXISTS ' . Util::backquote($tablename) . ";\n";
@@ -278,7 +287,7 @@ class Tracker
 
         if ($result) {
             // Deactivate previous version
-            self::deactivateTracking($dbname, $tablename, ($version - 1));
+            self::deactivateTracking($dbname, $tablename, (int) $version - 1);
         }
 
         return $result;
@@ -298,7 +307,7 @@ class Tracker
      */
     public static function deleteTracking($dbname, $tablename, $version = '')
     {
-        $relation = new Relation();
+        $relation = new Relation($GLOBALS['dbi']);
 
         $sql_query = "/*NOTRACK*/\n"
             . "DELETE FROM " . self::_getTrackingTable()
@@ -310,9 +319,7 @@ class Tracker
             $sql_query .= " AND `version` = '"
                 . $GLOBALS['dbi']->escapeString($version) . "'";
         }
-        $result = $relation->queryAsControlUser($sql_query);
-
-        return $result;
+        return $relation->queryAsControlUser($sql_query);
     }
 
     /**
@@ -328,10 +335,13 @@ class Tracker
      *
      * @return int result of version insertion
      */
-    public static function createDatabaseVersion($dbname, $version, $query,
+    public static function createDatabaseVersion(
+        $dbname,
+        $version,
+        $query,
         $tracking_set = 'CREATE DATABASE,ALTER DATABASE,DROP DATABASE'
     ) {
-        $relation = new Relation();
+        $relation = new Relation($GLOBALS['dbi']);
 
         $date = Util::date('Y-m-d H:i:s');
 
@@ -374,9 +384,7 @@ class Tracker
         '" . $GLOBALS['dbi']->escapeString($tracking_set)
         . "' )";
 
-        $result = $relation->queryAsControlUser($sql_query);
-
-        return $result;
+        return $relation->queryAsControlUser($sql_query);
     }
 
 
@@ -393,20 +401,21 @@ class Tracker
      *
      * @return int result of SQL query
      */
-    static private function _changeTracking($dbname, $tablename,
-        $version, $new_state
+    private static function _changeTracking(
+        $dbname,
+        $tablename,
+        $version,
+        $new_state
     ) {
-        $relation = new Relation();
+        $relation = new Relation($GLOBALS['dbi']);
 
         $sql_query = " UPDATE " . self::_getTrackingTable() .
         " SET `tracking_active` = '" . $new_state . "' " .
         " WHERE `db_name` = '" . $GLOBALS['dbi']->escapeString($dbname) . "' " .
         " AND `table_name` = '" . $GLOBALS['dbi']->escapeString($tablename) . "' " .
-        " AND `version` = '" . $GLOBALS['dbi']->escapeString($version) . "' ";
+        " AND `version` = '" . $GLOBALS['dbi']->escapeString((string) $version) . "' ";
 
-        $result = $relation->queryAsControlUser($sql_query);
-
-        return $result;
+        return $relation->queryAsControlUser($sql_query);
     }
 
     /**
@@ -422,10 +431,14 @@ class Tracker
      *
      * @return bool result of change
      */
-    public static function changeTrackingData($dbname, $tablename,
-        $version, $type, $new_data
+    public static function changeTrackingData(
+        $dbname,
+        $tablename,
+        $version,
+        $type,
+        $new_data
     ) {
-        $relation = new Relation();
+        $relation = new Relation($GLOBALS['dbi']);
 
         if ($type == 'DDL') {
             $save_to = 'schema_sql';
@@ -454,7 +467,7 @@ class Tracker
 
         $result = $relation->queryAsControlUser($sql_query);
 
-        return (boolean) $result;
+        return (bool) $result;
     }
 
     /**
@@ -505,7 +518,7 @@ class Tracker
      */
     public static function getVersion($dbname, $tablename, $statement = null)
     {
-        $relation = new Relation();
+        $relation = new Relation($GLOBALS['dbi']);
 
         $sql_query = " SELECT MAX(version) FROM " . self::_getTrackingTable() .
         " WHERE `db_name` = '" . $GLOBALS['dbi']->escapeString($dbname) . "' " .
@@ -536,7 +549,7 @@ class Tracker
      */
     public static function getTrackedData($dbname, $tablename, $version)
     {
-        $relation = new Relation();
+        $relation = new Relation($GLOBALS['dbi']);
 
         $sql_query = " SELECT * FROM " . self::_getTrackingTable() .
             " WHERE `db_name` = '" . $GLOBALS['dbi']->escapeString($dbname) . "' ";
@@ -545,27 +558,27 @@ class Tracker
                 . $GLOBALS['dbi']->escapeString($tablename) . "' ";
         }
         $sql_query .= " AND `version` = '" . $GLOBALS['dbi']->escapeString($version)
-            . "' " . " ORDER BY `version` DESC LIMIT 1";
+            . "' ORDER BY `version` DESC LIMIT 1";
 
         $mixed = $GLOBALS['dbi']->fetchAssoc($relation->queryAsControlUser($sql_query));
 
         // PHP 7.4 fix for accessing array offset on null
-        if (!is_array($mixed)) {
-            $mixed = array(
+        if (! is_array($mixed)) {
+            $mixed = [
                 'schema_sql' => null,
                 'data_sql' => null,
                 'tracking' => null,
                 'schema_snapshot' => null,
-            );
+            ];
         }
 
         // Parse log
-        $log_schema_entries = explode('# log ',  $mixed['schema_sql']);
-        $log_data_entries   = explode('# log ',  $mixed['data_sql']);
+        $log_schema_entries = explode('# log ', (string) $mixed['schema_sql']);
+        $log_data_entries   = explode('# log ', (string) $mixed['data_sql']);
 
         $ddl_date_from = $date = Util::date('Y-m-d H:i:s');
 
-        $ddlog = array();
+        $ddlog = [];
         $first_iteration = true;
 
         // Iterate tracked data definition statements
@@ -574,7 +587,9 @@ class Tracker
             if (trim($log_entry) != '') {
                 $date      = mb_substr($log_entry, 0, 19);
                 $username  = mb_substr(
-                    $log_entry, 20, mb_strpos($log_entry, "\n") - 20
+                    $log_entry,
+                    20,
+                    mb_strpos($log_entry, "\n") - 20
                 );
                 if ($first_iteration) {
                     $ddl_date_from = $date;
@@ -582,9 +597,11 @@ class Tracker
                 }
                 $statement = rtrim(mb_strstr($log_entry, "\n"));
 
-                $ddlog[] = array( 'date' => $date,
-                                  'username'=> $username,
-                                  'statement' => $statement );
+                $ddlog[] = [
+                    'date' => $date,
+                    'username' => $username,
+                    'statement' => $statement,
+                ];
             }
         }
 
@@ -593,7 +610,7 @@ class Tracker
 
         $dml_date_from = $date_from;
 
-        $dmlog = array();
+        $dmlog = [];
         $first_iteration = true;
 
         // Iterate tracked data manipulation statements
@@ -602,7 +619,9 @@ class Tracker
             if (trim($log_entry) != '') {
                 $date      = mb_substr($log_entry, 0, 19);
                 $username  = mb_substr(
-                    $log_entry, 20, mb_strpos($log_entry, "\n") - 20
+                    $log_entry,
+                    20,
+                    mb_strpos($log_entry, "\n") - 20
                 );
                 if ($first_iteration) {
                     $dml_date_from = $date;
@@ -610,16 +629,18 @@ class Tracker
                 }
                 $statement = rtrim(mb_strstr($log_entry, "\n"));
 
-                $dmlog[] = array( 'date' => $date,
-                                  'username' => $username,
-                                  'statement' => $statement );
+                $dmlog[] = [
+                    'date' => $date,
+                    'username' => $username,
+                    'statement' => $statement,
+                ];
             }
         }
 
         $dml_date_to = $date;
 
         // Define begin and end of date range for both logs
-        $data = array();
+        $data = [];
         if (strtotime($ddl_date_from) <= strtotime($dml_date_from)) {
             $data['date_from'] = $ddl_date_from;
         } else {
@@ -671,9 +692,9 @@ class Tracker
             $GLOBALS['db'] = $tokens[2]->value;
         }
 
-        $result = array();
+        $result = [];
 
-        if (!empty($parser->statements)) {
+        if (! empty($parser->statements)) {
             $statement = $parser->statements[0];
             $options   = isset($statement->options) ? $statement->options->options : null;
 
@@ -684,7 +705,7 @@ class Tracker
 
             // Parse CREATE statement
             if ($statement instanceof CreateStatement) {
-                if (empty($options) || !isset($options[6])) {
+                if (empty($options) || ! isset($options[6])) {
                     return $result;
                 }
 
@@ -701,18 +722,15 @@ class Tracker
                           || $options[6] == 'UNIQUE INDEX'
                           || $options[6] == 'FULLTEXT INDEX'
                           || $options[6] == 'SPATIAL INDEX'
-                ){
+                ) {
                     $result['identifier'] = 'CREATE INDEX';
 
                     // In case of CREATE INDEX, we have to get the table name from body of the statement
                     $result['tablename']  = $statement->body[3]->value == '.' ? $statement->body[4]->value
                                                                               : $statement->body[2]->value ;
                 }
-            }
-
-            // Parse ALTER statement
-            elseif ($statement instanceof AlterStatement) {
-                if (empty($options) || !isset($options[3])) {
+            } elseif ($statement instanceof AlterStatement) { // Parse ALTER statement
+                if (empty($options) || ! isset($options[3])) {
                     return $result;
                 }
 
@@ -725,11 +743,8 @@ class Tracker
 
                     $GLOBALS['db']          = $statement->table->table ;
                 }
-            }
-
-            // Parse DROP statement
-            elseif ($statement instanceof DropStatement) {
-                if (empty($options) || !isset($options[1])) {
+            } elseif ($statement instanceof DropStatement) { // Parse DROP statement
+                if (empty($options) || ! isset($options[1])) {
                     return $result;
                 }
 
@@ -745,10 +760,7 @@ class Tracker
                     $result['identifier']   = 'DROP INDEX' ;
                     $result['tablename']    = $statement->table->table;
                 }
-            }
-
-            // Prase RENAME statement
-            elseif ($statement instanceof RenameStatement) {
+            } elseif ($statement instanceof RenameStatement) { // Parse RENAME statement
                 $result['identifier']               = 'RENAME TABLE';
                 $result['tablename']                = $statement->renames[0]->old->table;
                 $result['tablename_after_rename']   = $statement->renames[0]->new->table;
@@ -803,7 +815,7 @@ class Tracker
      */
     public static function handleQuery($query)
     {
-        $relation = new Relation();
+        $relation = new Relation($GLOBALS['dbi']);
 
         // If query is marked as untouchable, leave
         if (mb_strstr($query, "/*NOTRACK*/")) {
@@ -811,7 +823,7 @@ class Tracker
         }
 
         if (! (substr($query, -1) == ';')) {
-            $query = $query . ";\n";
+            $query .= ";\n";
         }
         // Get some information about query
         $result = self::parseQuery($query);
@@ -831,7 +843,9 @@ class Tracker
             }
 
             $version = self::getVersion(
-                $dbname, $result['tablename'], $result['identifier']
+                $dbname,
+                $result['tablename'],
+                $result['identifier']
             );
 
             // If version not exists and auto-creation is enabled
@@ -841,17 +855,21 @@ class Tracker
                 // Create the version
 
                 switch ($result['identifier']) {
-                case 'CREATE TABLE':
-                    self::createVersion($dbname, $result['tablename'], '1');
-                    break;
-                case 'CREATE VIEW':
-                    self::createVersion(
-                        $dbname, $result['tablename'], '1', '', true
-                    );
-                    break;
-                case 'CREATE DATABASE':
-                    self::createDatabaseVersion($dbname, '1', $query);
-                    break;
+                    case 'CREATE TABLE':
+                        self::createVersion($dbname, $result['tablename'], '1');
+                        break;
+                    case 'CREATE VIEW':
+                        self::createVersion(
+                            $dbname,
+                            $result['tablename'],
+                            '1',
+                            '',
+                            true
+                        );
+                        break;
+                    case 'CREATE DATABASE':
+                        self::createDatabaseVersion($dbname, '1', $query);
+                        break;
                 } // end switch
             }
 
@@ -916,7 +934,7 @@ class Tracker
      */
     private static function _getTrackingTable()
     {
-        $relation = new Relation();
+        $relation = new Relation($GLOBALS['dbi']);
         $cfgRelation = $relation->getRelationsParam();
         return Util::backquote($cfgRelation['db'])
             . '.' . Util::backquote($cfgRelation['tracking']);
