@@ -5,6 +5,8 @@
  *
  * @package PhpMyAdmin
  */
+declare(strict_types=1);
+
 namespace PhpMyAdmin;
 
 /**
@@ -30,21 +32,23 @@ class Url
      *
      * @access  public
      */
-    public static function getHiddenInputs($db = '', $table = '',
-        $indent = 0, $skip = array()
+    public static function getHiddenInputs(
+        $db = '',
+        $table = '',
+        $indent = 0,
+        $skip = []
     ) {
+        /** @var Config $PMA_Config */
+        global $PMA_Config;
+
         if (is_array($db)) {
             $params  =& $db;
-            $_indent = empty($table) ? $indent : $table;
-            $_skip   = empty($indent) ? $skip : $indent;
-            $indent  =& $_indent;
-            $skip    =& $_skip;
         } else {
-            $params = array();
-            if (strlen($db) > 0) {
+            $params = [];
+            if (strlen((string) $db) > 0) {
                 $params['db'] = $db;
             }
-            if (strlen($table) > 0) {
+            if (strlen((string) $table) > 0) {
                 $params['table'] = $table;
             }
         }
@@ -54,7 +58,7 @@ class Url
         ) {
             $params['server'] = $GLOBALS['server'];
         }
-        if (empty($_COOKIE['pma_lang']) && ! empty($GLOBALS['lang'])) {
+        if (empty($PMA_Config->getCookie('pma_lang')) && ! empty($GLOBALS['lang'])) {
             $params['lang'] = $GLOBALS['lang'];
         }
 
@@ -91,24 +95,25 @@ class Url
      * echo Url::getHiddenFields($values);
      *
      * // produces:
-     * <input type="hidden" name="aaa" Value="aaa" />
-     * <input type="hidden" name="bbb[0]" Value="bbb_0" />
-     * <input type="hidden" name="bbb[1]" Value="bbb_1" />
-     * <input type="hidden" name="ccc[a]" Value="ccc_a" />
-     * <input type="hidden" name="ccc[b]" Value="ccc_b" />
+     * <input type="hidden" name="aaa" Value="aaa">
+     * <input type="hidden" name="bbb[0]" Value="bbb_0">
+     * <input type="hidden" name="bbb[1]" Value="bbb_1">
+     * <input type="hidden" name="ccc[a]" Value="ccc_a">
+     * <input type="hidden" name="ccc[b]" Value="ccc_b">
      * </code>
      *
-     * @param array  $values hidden values
-     * @param string $pre    prefix
+     * @param array  $values   hidden values
+     * @param string $pre      prefix
+     * @param bool   $is_token if token already added in hidden input field
      *
      * @return string form fields of type hidden
      */
-    public static function getHiddenFields(array $values, $pre = '')
+    public static function getHiddenFields(array $values, $pre = '', $is_token = false)
     {
         $fields = '';
 
         /* Always include token in plain forms */
-        if ($pre === '') {
+        if ($is_token === false) {
             $values['token'] = $_SESSION[' PMA_token '];
         }
 
@@ -118,13 +123,13 @@ class Url
             }
 
             if (is_array($value)) {
-                $fields .= Url::getHiddenFields($value, $name);
+                $fields .= Url::getHiddenFields($value, $name, true);
             } else {
                 // do not generate an ending "\n" because
                 // Url::getHiddenInputs() is sometimes called
                 // from a JS document.write()
-                $fields .= '<input type="hidden" name="' . htmlspecialchars($name)
-                    . '" value="' . htmlspecialchars($value) . '" />';
+                $fields .= '<input type="hidden" name="' . htmlspecialchars((string) $name)
+                    . '" value="' . htmlspecialchars((string) $value) . '">';
             }
         }
 
@@ -160,7 +165,7 @@ class Url
      * @return string   string with URL parameters
      * @access  public
      */
-    public static function getCommon($params = array(), $divider = '?')
+    public static function getCommon($params = [], $divider = '?')
     {
         return htmlspecialchars(
             Url::getCommonRaw($params, $divider)
@@ -196,24 +201,26 @@ class Url
      * @return string   string with URL parameters
      * @access  public
      */
-    public static function getCommonRaw($params = array(), $divider = '?')
+    public static function getCommonRaw($params = [], $divider = '?')
     {
+        /** @var Config $PMA_Config */
+        global $PMA_Config;
         $separator = Url::getArgSeparator();
 
         // avoid overwriting when creating navi panel links to servers
         if (isset($GLOBALS['server'])
             && $GLOBALS['server'] != $GLOBALS['cfg']['ServerDefault']
             && ! isset($params['server'])
-            && ! $GLOBALS['PMA_Config']->get('is_setup')
+            && ! $PMA_Config->get('is_setup')
         ) {
             $params['server'] = $GLOBALS['server'];
         }
 
-        if (empty($_COOKIE['pma_lang']) && ! empty($GLOBALS['lang'])) {
+        if (empty($PMA_Config->getCookie('pma_lang')) && ! empty($GLOBALS['lang'])) {
             $params['lang'] = $GLOBALS['lang'];
         }
 
-        $query = http_build_query($params, null, $separator);
+        $query = http_build_query($params, '', $separator);
 
         if ($divider != '?' || strlen($query) > 0) {
             return $divider . $query;
@@ -229,7 +236,7 @@ class Url
      * we do not use arg_separator.output to avoid problems with &amp; and &
      *
      * @param string $encode whether to encode separator or not,
-     * currently 'none' or 'html'
+     *                       currently 'none' or 'html'
      *
      * @return string  character used for separating url parts usually ; or &
      * @access  public
@@ -256,12 +263,12 @@ class Url
         }
 
         switch ($encode) {
-        case 'html':
-            return $html_separator;
-        case 'text' :
-        case 'none' :
-        default :
-            return $separator;
+            case 'html':
+                return $html_separator;
+            case 'text':
+            case 'none':
+            default:
+                return $separator;
         }
     }
 }
