@@ -30,20 +30,24 @@
  *
  * @package PhpMyAdmin
  */
+declare(strict_types=1);
 
 use PhpMyAdmin\Config;
 use PhpMyAdmin\Core;
 use PhpMyAdmin\DatabaseInterface;
+use PhpMyAdmin\Di\Migration;
 use PhpMyAdmin\ErrorHandler;
 use PhpMyAdmin\LanguageManager;
 use PhpMyAdmin\Logging;
 use PhpMyAdmin\Message;
-use PhpMyAdmin\Plugins\AuthenticationPlugin;
 use PhpMyAdmin\Response;
 use PhpMyAdmin\Session;
 use PhpMyAdmin\ThemeManager;
 use PhpMyAdmin\Tracker;
 use PhpMyAdmin\Util;
+use Symfony\Component\Config\FileLocator;
+use Symfony\Component\DependencyInjection\ContainerBuilder;
+use Symfony\Component\DependencyInjection\Loader\YamlFileLoader;
 
 /**
  * block attempts to directly run this script
@@ -56,9 +60,9 @@ if (getcwd() == dirname(__FILE__)) {
  * Minimum PHP version; can't call Core::fatalError() which uses a
  * PHP 5 function, so cannot easily localize this message.
  */
-if (version_compare(PHP_VERSION, '5.5.0', 'lt')) {
+if (version_compare(PHP_VERSION, '7.1.3', 'lt')) {
     die(
-        'PHP 5.5+ is required. <br /> Currently installed version is: '
+        'PHP 7.1.3+ is required. <br> Currently installed version is: '
         . phpversion()
     );
 }
@@ -71,34 +75,34 @@ define('PHPMYADMIN', true);
 /**
  * Load vendor configuration.
  */
-require_once './libraries/vendor_config.php';
-
-/**
- * Load hash polyfill.
- */
-require_once './libraries/hash.lib.php';
+require_once ROOT_PATH . 'libraries/vendor_config.php';
 
 /**
  * Activate autoloader
  */
 if (! @is_readable(AUTOLOAD_FILE)) {
     die(
-        'File <tt>' . AUTOLOAD_FILE . '</tt> missing or not readable. <br />'
+        'File <tt>' . AUTOLOAD_FILE . '</tt> missing or not readable. <br>'
         . 'Most likely you did not run Composer to '
         . '<a href="https://docs.phpmyadmin.net/en/latest/setup.html#installing-from-git">install library files</a>.'
     );
 }
 require_once AUTOLOAD_FILE;
 
+$containerBuilder = new ContainerBuilder();
+$loader = new YamlFileLoader($containerBuilder, new FileLocator(__DIR__));
+$loader->load('../services.yml');
+$loader->load('../services_controllers.yml');
+/** @var Migration $diMigration */
+$diMigration = $containerBuilder->get('di_migration');
+
 /**
  * Load gettext functions.
  */
 PhpMyAdmin\MoTranslator\Loader::loadFunctions();
 
-/**
- * initialize the error handler
- */
-$GLOBALS['error_handler'] = new ErrorHandler();
+/** @var ErrorHandler $GLOBALS['error_handler'] */
+$GLOBALS['error_handler'] = $containerBuilder->get('error_handler');
 
 /**
  * Warning about missing PHP extensions.
@@ -123,7 +127,8 @@ Core::cleanupPathInfo();
  * force reading of config file, because we removed sensitive values
  * in the previous iteration
  */
-$GLOBALS['PMA_Config'] = new Config(CONFIG_FILE);
+$GLOBALS['PMA_Config'] = $containerBuilder->get('config');
+//$containerBuilder->set('config', $GLOBALS['PMA_Config']);
 
 /**
  * include session handling after the globals, to prevent overwriting
@@ -140,17 +145,17 @@ if (! defined('PMA_NO_SESSION')) {
  * holds parameters to be passed to next page
  * @global array $GLOBALS['url_params']
  */
-$GLOBALS['url_params'] = array();
+$diMigration->setGlobal('url_params', []);
 
 /**
  * holds page that should be displayed
  * @global string $GLOBALS['goto']
  */
-$GLOBALS['goto'] = '';
+$diMigration->setGlobal('goto', '');
 // Security fix: disallow accessing serious server files via "?goto="
-if (Core::checkPageValidity($_REQUEST['goto'])) {
-    $GLOBALS['goto'] = $_REQUEST['goto'];
-    $GLOBALS['url_params']['goto'] = $_REQUEST['goto'];
+if (isset($_REQUEST['goto']) && Core::checkPageValidity($_REQUEST['goto'])) {
+    $diMigration->setGlobal('goto', $_REQUEST['goto']);
+    $diMigration->setGlobal('url_params', ['goto' => $_REQUEST['goto']]);
 } else {
     $GLOBALS['PMA_Config']->removeCookie('goto');
     unset($_REQUEST['goto'], $_GET['goto'], $_POST['goto']);
@@ -160,8 +165,8 @@ if (Core::checkPageValidity($_REQUEST['goto'])) {
  * returning page
  * @global string $GLOBALS['back']
  */
-if (Core::checkPageValidity($_REQUEST['back'])) {
-    $GLOBALS['back'] = $_REQUEST['back'];
+if (isset($_REQUEST['back']) && Core::checkPageValidity($_REQUEST['back'])) {
+    $diMigration->setGlobal('back', $_REQUEST['back']);
 } else {
     $GLOBALS['PMA_Config']->removeCookie('back');
     unset($_REQUEST['back'], $_GET['back'], $_POST['back']);
@@ -207,7 +212,7 @@ if ($_SERVER['REQUEST_METHOD'] == 'POST') {
          * We don't allow any POST operation parameters if the token is mismatched
          * or is not provided
          */
-        $whitelist = array('ajax_request');
+        $whitelist = ['ajax_request'];
         PhpMyAdmin\Sanitize::removeRequestVars($whitelist);
     }
 }
@@ -229,27 +234,35 @@ Core::setGlobalDbOrTable('table');
  * Store currently selected recent table.
  * Affect $GLOBALS['db'] and $GLOBALS['table']
  */
-if (Core::isValid($_REQUEST['selected_recent_table'])) {
+if (isset($_REQUEST['selected_recent_table']) && Core::isValid($_REQUEST['selected_recent_table'])) {
     $recent_table = json_decode($_REQUEST['selected_recent_table'], true);
 
-    $GLOBALS['db']
-        = (array_key_exists('db', $recent_table) && is_string($recent_table['db'])) ?
-            $recent_table['db'] : '';
-    $GLOBALS['url_params']['db'] = $GLOBALS['db'];
+    $diMigration->setGlobal(
+        'db',
+        (array_key_exists('db', $recent_table) && is_string($recent_table['db'])) ? $recent_table['db'] : ''
+    );
+    $diMigration->setGlobal(
+        'url_params',
+        ['db' => $containerBuilder->getParameter('db')] + $containerBuilder->getParameter('url_params')
+    );
 
-    $GLOBALS['table']
-        = (array_key_exists('table', $recent_table) && is_string($recent_table['table'])) ?
-            $recent_table['table'] : '';
-    $GLOBALS['url_params']['table'] = $GLOBALS['table'];
+    $diMigration->setGlobal(
+        'table',
+        (array_key_exists('table', $recent_table) && is_string($recent_table['table'])) ? $recent_table['table'] : ''
+    );
+    $diMigration->setGlobal(
+        'url_params',
+        ['table' => $containerBuilder->getParameter('table')] + $containerBuilder->getParameter('url_params')
+    );
 }
 
 /**
  * SQL query to be executed
  * @global string $GLOBALS['sql_query']
  */
-$GLOBALS['sql_query'] = '';
+$diMigration->setGlobal('sql_query', '');
 if (Core::isValid($_POST['sql_query'])) {
-    $GLOBALS['sql_query'] = $_POST['sql_query'];
+    $diMigration->setGlobal('sql_query', $_POST['sql_query']);
 }
 
 //$_REQUEST['set_theme'] // checked later in this file LABEL_theme_setup
@@ -287,8 +300,8 @@ $GLOBALS['PMA_Config']->checkServers();
  * current server
  * @global integer $GLOBALS['server']
  */
-$GLOBALS['server'] = $GLOBALS['PMA_Config']->selectServer();
-$GLOBALS['url_params']['server'] = $GLOBALS['server'];
+$diMigration->setGlobal('server', $GLOBALS['PMA_Config']->selectServer());
+$diMigration->setGlobal('url_params', ['server' => $containerBuilder->getParameter('server')] + $containerBuilder->getParameter('url_params'));
 
 /**
  * BC - enable backward compatibility
@@ -301,6 +314,8 @@ $GLOBALS['PMA_Config']->enableBc();
 
 ThemeManager::initializeTheme();
 
+$GLOBALS['dbi'] = null;
+
 if (! defined('PMA_MINIMUM_COMMON')) {
     /**
      * save some settings in cookies
@@ -311,11 +326,11 @@ if (! defined('PMA_MINIMUM_COMMON')) {
     ThemeManager::getInstance()->setThemeCookie();
 
     if (! empty($cfg['Server'])) {
-
         /**
          * Loads the proper database interface for this server
          */
-        DatabaseInterface::load();
+        $containerBuilder->set(DatabaseInterface::class, DatabaseInterface::load());
+        $containerBuilder->setAlias('dbi', DatabaseInterface::class);
 
         // get LoginCookieValidity from preferences cache
         // no generic solution for loading preferences from cache as some settings
@@ -395,17 +410,19 @@ if (! defined('PMA_MINIMUM_COMMON')) {
         if ($GLOBALS['dbi']->getVersion() < $cfg['MysqlMinVersion']['internal']) {
             Core::fatalError(
                 __('You should upgrade to %s %s or later.'),
-                array('MySQL', $cfg['MysqlMinVersion']['human'])
+                [
+                    'MySQL',
+                    $cfg['MysqlMinVersion']['human'],
+                ]
             );
         }
 
         // Sets the default delimiter (if specified).
-        if (!empty($_REQUEST['sql_delimiter'])) {
+        if (! empty($_REQUEST['sql_delimiter'])) {
             PhpMyAdmin\SqlParser\Lexer::$DEFAULT_DELIMITER = $_REQUEST['sql_delimiter'];
         }
 
         // TODO: Set SQL modes too.
-
     } else { // end server connecting
         $response = Response::getInstance();
         $response->getHeader()->disableMenuAndConsole();
@@ -451,10 +468,22 @@ if (! defined('PMA_MINIMUM_COMMON')) {
         );
         exit;
     }
+
+    $containerBuilder->set('response', Response::getInstance());
 }
 
 // load user preferences
 $GLOBALS['PMA_Config']->loadUserPreferences();
 
+$containerBuilder->set('theme_manager', ThemeManager::getInstance());
+
 /* Tell tracker that it can actually work */
 Tracker::enable();
+
+if (! defined('PMA_MINIMUM_COMMON')
+    && ! empty($GLOBALS['server'])
+    && isset($GLOBALS['cfg']['ZeroConf'])
+    && $GLOBALS['cfg']['ZeroConf'] == true
+) {
+    $GLOBALS['dbi']->postConnectControl();
+}
